@@ -1,29 +1,13 @@
-/* -*- Mode: C++; indent-tabs-mode: nil; tab-width: 4 -*-
- * -*- coding: utf-8 -*-
- *
- * Copyright (C) 2011 ~ 2018 Deepin, Inc.
- *
- * Author:     Wang Yong <wangyong@deepin.com>
- * Maintainer: Rekols    <rekols@foxmail.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+// SPDX-FileCopyrightText: 2011-2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
+
 #include "utils.h"
 #include "settings.h"
 
 #include "dthememanager.h"
 #include "../controls/fontitemdelegate.h"
+#include "../widgets/pathsettintwgt.h"
 #include <DSettings>
 #include <DSettingsGroup>
 #include <DSettingsWidgetFactory>
@@ -148,6 +132,63 @@ Settings::Settings(QWidget *parent)
     connect(settings, &Dtk::Core::DSettings::valueChanged, this, &Settings::slotCustomshortcut);
 }
 
+void Settings::setSavePath(int id,const QString& path)
+{
+    switch (id) {
+    case PathSettingWgt::LastOptBox:{
+        auto opt = settings->option("advance.open_save_setting.open_save_lastopt_path");
+        opt->setValue(path);
+        break;
+    }
+    case PathSettingWgt::CurFileBox:{
+        auto opt = settings->option("advance.open_save_setting.open_save_curfile_path");
+        opt->setValue(path);
+        break;
+    }
+    case PathSettingWgt::CustomBox:{
+        auto opt = settings->option("advance.open_save_setting.open_save_custom_path");
+        opt->setValue(path);
+        break;
+    }
+    default:
+        break;
+    }
+}
+
+
+QString Settings::getSavePath(int id)
+{
+    QString path;
+    switch (id) {
+    case PathSettingWgt::LastOptBox:{
+        path = settings->option("advance.open_save_setting.open_save_lastopt_path")->value().toString();
+        break;
+    }
+    case PathSettingWgt::CurFileBox:{
+        path = settings->option("advance.open_save_setting.open_save_curfile_path")->value().toString();
+        break;
+    }
+    case PathSettingWgt::CustomBox:{
+        path = settings->option("advance.open_save_setting.open_save_custom_path")->value().toString();
+        break;
+    }
+    default:
+        break;
+    }
+
+    return path;
+}
+
+void Settings::setSavePathId(int id)
+{
+    auto opt = settings->option("advance.open_save_setting.savingpathwgt");
+    opt->setValue(QString::number(id));
+}
+int Settings::getSavePathId()
+{
+   return settings->option("advance.open_save_setting.savingpathwgt")->value().toInt();
+
+}
 Settings::~Settings()
 {
     if (m_backend != nullptr) {
@@ -208,6 +249,27 @@ QPair<QWidget *, QWidget *> Settings::createFontComBoBoxHandle(QObject *obj)
     return optionWidget;
 }
 
+QWidget* Settings::createSavingPathWgt(QObject* obj)
+{
+    auto option = qobject_cast<DTK_CORE_NAMESPACE::DSettingsOption *>(obj);
+    QString name = option->name();
+    PathSettingWgt* pathwgt = new PathSettingWgt;
+    QPair<QWidget *, QWidget *> optionWidget = DSettingsWidgetFactory::createStandardItem(QByteArray(), option, pathwgt);
+
+    connect(option, &DSettingsOption::valueChanged, pathwgt, [ = ](QVariant var) {
+        int id = var.toInt();
+        pathwgt->onSaveIdChanged(id);
+    });
+
+    auto custompath = s_pSetting->settings->option("advance.open_save_setting.open_save_custom_path");
+    connect(custompath, &Dtk::Core::DSettingsOption::valueChanged, [=](QVariant var){
+        //pathwgt->setEditText(var.toString());
+    });
+
+
+    return optionWidget.second;
+}
+
 QPair<QWidget *, QWidget *> Settings::createKeySequenceEditHandle(QObject *obj)
 {
     auto option = qobject_cast<DTK_CORE_NAMESPACE::DSettingsOption *>(obj);
@@ -228,10 +290,19 @@ QPair<QWidget *, QWidget *> Settings::createKeySequenceEditHandle(QObject *obj)
         QStringList keySplitList = option->key().split(".");
         keySplitList[1] = QString("%1_keymap_%2").arg(keySplitList[1]).arg(keymap->value().toString());
 
-        if (!instance()->checkShortcutValid(checkName, sequence.toString(), reason, bIsConflicts)) {
+        // 获取默认设置的组合键序列
+        QString defaultKey;
+        auto defaultOption = instance()->settings->option(keySplitList.join("."));
+        if (defaultOption) {
+            defaultKey = defaultOption->defaultValue().toString();
+        }
+
+        // 判断新设置的组合键序列是否允许
+        if (!instance()->checkShortcutValid(checkName, sequence.toString(), reason, bIsConflicts, defaultKey)) {
             instance()->m_pDialog = instance()->createDialog(reason, "", bIsConflicts);
             instance()->m_pDialog->exec();
-            shortCutLineEdit->setKeySequence(QKeySequence(instance()->settings->value(keySplitList.join(".")).toString()));
+            // 恢复组合键序列
+            shortCutLineEdit->setKeySequence(instance()->settings->value(keySplitList.join(".")).toString());
             keymap->setValue("emacs");
             keymap->setValue("customize");
             return;
@@ -244,36 +315,36 @@ QPair<QWidget *, QWidget *> Settings::createKeySequenceEditHandle(QObject *obj)
         if (keymap->value().toString() != "customize") {
             instance()->m_bUserChangeKey = true;
 
-            for (auto option : instance()->settings->group("shortcuts.window_keymap_customize")->options()) {
-                QStringList keySplitList = option->key().split(".");
-                keySplitList[1] = QString("window_keymap_%1").arg(keymap->value().toString());
+            for (auto loopOption : instance()->settings->group("shortcuts.window_keymap_customize")->options()) {
+                QStringList loopKeySplitList = loopOption->key().split(".");
+                loopKeySplitList[1] = QString("window_keymap_%1").arg(keymap->value().toString());
 
-                if (option->value().toString() == sequence.toString()) {
+                if (loopOption->value().toString() == sequence.toString()) {
 
-                    if (checkName.contains(keySplitList.last())) {
+                    if (checkName.contains(loopKeySplitList.last())) {
                         keymap->setValue("customize");
                         //return;
                     } else {
                         bIsConflicts = true;
-                        keySplitList[1] = QString("window_keymap_%1").arg("customize");
-                        conflictsKeys = keySplitList.join(".");
+                        loopKeySplitList[1] = QString("window_keymap_%1").arg("customize");
+                        conflictsKeys = loopKeySplitList.join(".");
                     }
                 }
             }
 
-            for (auto option : instance()->settings->group("shortcuts.editor_keymap_customize")->options()) {
-                QStringList keySplitList = option->key().split(".");
-                keySplitList[1] = QString("editor_keymap_%1").arg(keymap->value().toString());
+            for (auto loopOption : instance()->settings->group("shortcuts.editor_keymap_customize")->options()) {
+                QStringList loopKeySplitList = loopOption->key().split(".");
+                loopKeySplitList[1] = QString("editor_keymap_%1").arg(keymap->value().toString());
 
-                if (option->value().toString() == sequence.toString()) {
+                if (loopOption->value().toString() == sequence.toString()) {
 
-                    if (checkName.contains(keySplitList.last())) {
+                    if (checkName.contains(loopKeySplitList.last())) {
                         keymap->setValue("customize");
                         //return;
                     } else {
                         bIsConflicts = true;
-                        keySplitList[1] = QString("editor_keymap_%1").arg("customize");
-                        conflictsKeys = keySplitList.join(".");
+                        loopKeySplitList[1] = QString("editor_keymap_%1").arg("customize");
+                        conflictsKeys = loopKeySplitList.join(".");
                     }
                 }
             }
@@ -282,32 +353,32 @@ QPair<QWidget *, QWidget *> Settings::createKeySequenceEditHandle(QObject *obj)
         }  else {
             bIsCustomize = true;
             instance()->m_bUserChangeKey = true;
-            for (auto option : instance()->settings->group("shortcuts.window_keymap_customize")->options()) {
-                QStringList keySplitList = option->key().split(".");
-                keySplitList[1] = QString("window_keymap_%1").arg(keymap->value().toString());
+            for (auto loopOption : instance()->settings->group("shortcuts.window_keymap_customize")->options()) {
+                QStringList loopKeySplitList = loopOption->key().split(".");
+                loopKeySplitList[1] = QString("window_keymap_%1").arg(keymap->value().toString());
 
-                if (option->value().toString() == sequence.toString()) {
+                if (loopOption->value().toString() == sequence.toString()) {
 
-                    if (checkName.contains(keySplitList.last())) {
+                    if (checkName.contains(loopKeySplitList.last())) {
                         //return;
                     } else {
                         bIsConflicts = true;
-                        conflictsKeys = keySplitList.join(".");
+                        conflictsKeys = loopKeySplitList.join(".");
                     }
                 }
             }
 
-            for (auto option : instance()->settings->group("shortcuts.editor_keymap_customize")->options()) {
-                QStringList keySplitList = option->key().split(".");
-                keySplitList[1] = QString("editor_keymap_%1").arg(keymap->value().toString());
+            for (auto loopOption : instance()->settings->group("shortcuts.editor_keymap_customize")->options()) {
+                QStringList loopKeySplitList = loopOption->key().split(".");
+                loopKeySplitList[1] = QString("editor_keymap_%1").arg(keymap->value().toString());
 
-                if (option->value().toString() == sequence.toString()) {
+                if (loopOption->value().toString() == sequence.toString()) {
 
-                    if (checkName.contains(keySplitList.last())) {
+                    if (checkName.contains(loopKeySplitList.last())) {
                         //return;
                     } else {
                         bIsConflicts = true;
-                        conflictsKeys = keySplitList.join(".");
+                        conflictsKeys = loopKeySplitList.join(".");
                     }
                 }
             }
@@ -464,7 +535,7 @@ void Settings::copyCustomizeKeysFromKeymap(QString keymap)
     m_bUserChangeKey = false;
 }
 
-bool Settings::checkShortcutValid(const QString &Name, QString Key, QString &Reason, bool &bIsConflicts)
+bool Settings::checkShortcutValid(const QString &Name, QString Key, QString &Reason, bool &bIsConflicts, QString defaultValue)
 {
     Q_UNUSED(Name);
 
@@ -491,14 +562,14 @@ bool Settings::checkShortcutValid(const QString &Name, QString Key, QString &Rea
         return  false;
     }
 
-//    // 与设置里的快捷键冲突检测
-//    if (isShortcutConflict(Name, Key)) {
-//        Reason = tr("This shortcut key conflicts with %1, click add to make this shortcut key take effect immediately").arg(style);
-//        bIsConflicts = true;
-//        return  false;
-//    }
+    // 屏蔽Shift组合键处理，但允许恢复为默认组合键序列
+    if (Key.contains("Shift")
+            && Key != defaultValue) {
+        Reason = tr("The shortcut %1 is invalid, please set another one.").arg(style);
+        bIsConflicts = false;
+        return false;
+    }
 
-//    bIsConflicts = true;
     return true;
 }
 
@@ -589,7 +660,7 @@ void Settings::slotsigAdjustFont(QVariant value)
 
 void Settings::slotsigAdjustFontSize(QVariant value)
 {
-    emit sigAdjustFontSize(value.toInt());
+    emit sigAdjustFontSize(value.toReal());
 }
 
 void Settings::slotsigAdjustWordWrap(QVariant value)
