@@ -1,30 +1,14 @@
-/* -*- Mode: C++; indent-tabs-mode: nil; tab-width: 4 -*-
- * -*- coding: utf-8 -*-
- *
- * Copyright (C) 2011 ~ 2018 Deepin, Inc.
- *
- * Author:     Wang Yong <wangyong@deepin.com>
- * Maintainer: Rekols    <rekols@foxmail.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+// SPDX-FileCopyrightText: 2011-2023 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
 
 #include "utils.h"
 
 #include <DSettings>
 #include <DSettingsOption>
 #include <DMessageManager>
+#include <DSysInfo>
+
 #include <QRegularExpression>
 #include <QJsonDocument>
 #include <QMimeDatabase>
@@ -44,6 +28,8 @@
 #include <QCryptographicHash>
 #include "qprocess.h"
 
+DCORE_USE_NAMESPACE
+
 QT_BEGIN_NAMESPACE
 extern Q_WIDGETS_EXPORT void qt_blurImage(QPainter *p, QImage &blurImage, qreal radius, bool quality, bool alphaOnly, int transposed = 0);
 QT_END_NAMESPACE
@@ -411,6 +397,11 @@ QString Utils::getKeyshortcut(QKeyEvent *keyEvent)
         if (modifiers.testFlag(Qt::ShiftModifier)) {
             keys.append("Shift");
         }
+
+        // 添加小键盘处理，若为小键盘按键按下，组合键需添加 Num ，例如 Ctrl+Num+6 / Ctrl+Num+Up
+        if (modifiers.testFlag(Qt::KeypadModifier)) {
+            keys.append("Num");
+        }
     }
 
     if (keyEvent->key() != 0 && keyEvent->key() != Qt::Key_unknown) {
@@ -614,6 +605,18 @@ QStringList Utils::cleanPath(const QStringList &filePaths)
     return paths;
 }
 
+/**
+ * @return 返回程序使用的默认数据(存放临时、备份文件)存放位置，不同环境下路径不同
+ *  [debian]    /home/user/.local/share/deepin/deepin-editor/
+ *  [linglong]  /home/user/.linglong/org.deepin.editor/share/deepin/deepin-editor/
+ */
+QString Utils::localDataPath()
+{
+    auto dataPaths = Utils::cleanPath(QStandardPaths::standardLocations(QStandardPaths::DataLocation));
+    return dataPaths.isEmpty() ? QDir::homePath() + "/.local/share/deepin/deepin-editor/"
+           : dataPaths.first();
+}
+
 const QStringList Utils::getEncodeList()
 {
     QStringList encodeList;
@@ -781,14 +784,29 @@ QString Utils::getStringMD5Hash(const QString &input)
 bool Utils::activeWindowFromDock(quintptr winId)
 {
     bool bRet = true;
-    // new interface use application as id
-    QDBusInterface dockDbusInterface("com.deepin.dde.daemon.Dock",
-                                     "/com/deepin/dde/daemon/Dock",
-                                     "com.deepin.dde.daemon.Dock");
-    QDBusReply<void> reply = dockDbusInterface.call("ActivateWindow", winId);
-    if (!reply.isValid()) {
-        qDebug() << "call com.deepin.dde.daemon.Dock failed" << reply.error();
-        bRet = false;
+    // 优先采用V23接口
+    QDBusInterface dockDbusInterfaceV23("org.deepin.dde.daemon.Dock1",
+                                        "/org/deepin/dde/daemon/Dock1",
+                                        "org.deepin.dde.daemon.Dock1");
+    if (dockDbusInterfaceV23.isValid()) {
+        QDBusReply<void> reply = dockDbusInterfaceV23.call("ActivateWindow", winId);
+        if (!reply.isValid()) {
+            qDebug() << "call v23 org.deepin.dde.daemon.Dock1 failed" << reply.error();
+            bRet = false;
+        } else {
+            return bRet;
+        }
+    }
+
+    QDBusInterface dockDbusInterfaceV20("com.deepin.dde.daemon.Dock",
+                                        "/com/deepin/dde/daemon/Dock",
+                                        "com.deepin.dde.daemon.Dock");
+    if (dockDbusInterfaceV20.isValid() && !bRet) {
+        QDBusReply<void> reply = dockDbusInterfaceV20.call("ActivateWindow", winId);
+        if (!reply.isValid()) {
+            qDebug() << "call v20 com.deepin.dde.daemon.Dock failed" << reply.error();
+            bRet = false;
+        }
     }
 
     return bRet;
@@ -823,16 +841,39 @@ QString Utils::getSystemLan()
     if (!m_systemLanguage.isEmpty()) {
         return m_systemLanguage;
     } else {
-        QDBusInterface ie("com.deepin.daemon.LangSelector",
-                          "/com/deepin/daemon/LangSelector",
-                          "com.deepin.daemon.LangSelector",
-                          QDBusConnection::sessionBus());
+        switch (getSystemVersion()) {
+            case V23:
+                m_systemLanguage = QLocale::system().name();
+                break;
+            default: {
+                QDBusInterface ie("com.deepin.daemon.LangSelector",
+                                "/com/deepin/daemon/LangSelector",
+                                "com.deepin.daemon.LangSelector",
+                                QDBusConnection::sessionBus());
+                m_systemLanguage = ie.property("CurrentLocale").toString();
+                break;
+            }
+        }
 
-        m_systemLanguage = ie.property("CurrentLocale").toString();
+        qWarning() << "getSystemLan is" << m_systemLanguage;
         return m_systemLanguage;
     }
 }
 
+/**
+ * @return 获取当前系统版本并返回
+ */
+Utils::SystemVersion Utils::getSystemVersion()
+{
+    QString version = DSysInfo::majorVersion();
+    if ("23" == version) {
+        return V23;
+    }
+
+    // 其它版本默认V20
+    return V20;
+}
+
 
 //judge whether the protocol is wayland
 bool Utils::isWayland()
@@ -913,3 +954,50 @@ Utils::RegionIntersectType Utils::checkRegionIntersect(int x1, int y1, int x2, i
         }
     }
 }
+
+/**
+ * @return 取得当前文本编辑器支持的编码格式，按区域划分，从文件 :/encodes/encodes.ini 中读取
+ * @note 非多线程安全，仅在 gui 线程调用
+ */
+QVector<QPair<QString, QStringList> > Utils::getSupportEncoding()
+{
+    static QVector<QPair<QString, QStringList> > s_groupEncodeVec;
+    if (s_groupEncodeVec.isEmpty()) {
+        QVector<QPair<QString, QStringList> > tmpEncodeVec;
+
+        QFile file(":/encodes/encodes.ini");
+        QString data;
+        if (file.open(QIODevice::ReadOnly)) {
+            data = QString::fromUtf8(file.readAll());
+            file.close();
+        }
+
+        QTextStream readStream(&data,QIODevice::ReadOnly);
+        while (!readStream.atEnd()) {
+            QString group = readStream.readLine();
+            QString key = group.mid(1,group.length()-2);
+            QString encodes = readStream.readLine();
+            QString value = encodes.mid(8,encodes.length()-2);
+            tmpEncodeVec.append(QPair<QString,QStringList>(key, value.split(",")));
+        }
+
+        s_groupEncodeVec = tmpEncodeVec;
+    }
+
+    return s_groupEncodeVec;
+}
+
+/**
+ * @return 取得当前文本编辑器支持的编码格式列表
+ */
+QStringList Utils::getSupportEncodingList()
+{
+    QStringList encodingList;
+    auto supportEncoding = getSupportEncoding();
+    for (auto encodingData : supportEncoding) {
+        encodingList.append(encodingData.second);
+    }
+    std::sort(encodingList.begin(), encodingList.end());
+
+    return encodingList;
+}
