@@ -1,24 +1,6 @@
-/* -*- Mode: C++; indent-tabs-mode: nil; tab-width: 4 -*-
- * -*- coding: utf-8 -*-
- *
- * Copyright (C) 2011 ~ 2018 Deepin, Inc.
- *
- * Author:     Wang Yong <wangyong@deepin.com>
- * Maintainer: Rekols    <rekols@foxmail.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+// SPDX-FileCopyrightText: 2011-2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
 
 #ifndef JUMPLINEBAR_H
 #define JUMPLINEBAR_H
@@ -32,12 +14,10 @@
 #include <DSpinBox>
 #include <QLineEdit>
 #include <QEvent>
+#include <DIconButton>
 
 DWIDGET_USE_NAMESPACE
 
-const int nJumpLineBarWidth = 212;
-const int nJumpLineBarHeight = 60;
-
 class JumpLineBar : public DFloatingWidget
 {
     Q_OBJECT
@@ -76,6 +56,7 @@ private:
     int m_columnBeforeJump;
     int m_lineCount;
     QColor m_backgroundColor;
+    DIconButton *m_closeButton=nullptr;
 };
 
 #endif
