@@ -1,21 +1,6 @@
-/*
- * Copyright (C) 2017 ~ 2018 Deepin Technology Co., Ltd.
- *
- * Author:     rekols <rekols@foxmail.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+// SPDX-FileCopyrightText: 2017 - 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
 
 #include "tabbar.h"
 #include "../widgets/window.h"
@@ -34,6 +19,29 @@
 
 QPixmap *Tabbar::sm_pDragPixmap = nullptr;
 
+/**
+ * @brief ‘&’在Qt中被标记为助记符，替换 \a str 中的‘&’字符为“&&”，以正确显示文件名中的‘&’符号
+ *      painter 绘制 CE_ToolButtonLabel 时设置了 Qt::TextShowMnemonic
+ * @note 在插入、新建标签页时，内部已使用替换，部分外部更新标签页名称，需手动处理
+ * @sa Tabbar::addTabWithIndex(), Tabbar::insertFromMimeData(), Tabbar::setTabText()
+ */
+QString replaceMnemonic(const QString &str)
+{
+    QString tmp = str;
+    tmp.replace(QChar('&'), QString("&&"));
+    return tmp;
+}
+
+/**
+ * @brief ‘&’在Qt中被标记为助记符，替换 \a str 中的"&&字符为'&'，以正确取得文件名中的‘&’符号
+ */
+QString restoreMnemonic(const QString &str)
+{
+    QString tmp = str;
+    tmp.replace(QString("&&"), QChar('&'));
+    return tmp;
+}
+
 Tabbar::Tabbar(QWidget *parent)
     : DTabBar(parent)
 {
@@ -84,12 +92,13 @@ void Tabbar::addTabWithIndex(int index, const QString &filePath, const QString &
     m_tabPaths.insert(index, filePath);
     m_tabTruePaths.insert(index, tipPath);
     // }
-    //除去空白符 梁卫东 ２０２０－０８－２６　１４：４９：１５
-    QString trimmedName = tabName.simplified();
+
+    // 除去空白符 梁卫东 ２０２０－０８－２６　１４：４９：１５ ；适配助记符
+    QString trimmedName = replaceMnemonic(tabName.simplified());
     DTabBar::insertTab(index, trimmedName);
     DTabBar::setCurrentIndex(index);
-    if (filePath.contains("/.local/share/deepin/deepin-editor/")) {
-        if (filePath.contains("/.local/share/deepin/deepin-editor/backup-files") && !tipPath.isNull() && tipPath.length() > 0) {
+    if (filePath.contains(Utils::localDataPath())) {
+        if (Utils::isBackupFile(filePath) && !tipPath.isNull() && tipPath.length() > 0) {
             setTabToolTip(index, tipPath);
         } else {
             setTabToolTip(index, tabName);
@@ -222,12 +231,13 @@ void Tabbar::closeRightTabs(const QString &filePath)
 
 void Tabbar::updateTab(int index, const QString &filePath, const QString &tabName)
 {
-    DTabBar::setTabText(index, tabName);
+    // 适配助记符 '&' 后设置文本
+    setTabText(index, tabName);
     m_tabPaths[index] = filePath;
     m_tabTruePaths[index] = filePath;
-    //show file path at tab,blank file only show it's name.
 
-    if (filePath.contains("/.local/share/deepin/deepin-editor/")) {
+    //show file path at tab,blank file only show it's name.
+    if (filePath.contains(Utils::localDataPath())) {
         setTabToolTip(index, tabName);
     } else {
         QString path = filePath;
@@ -281,7 +291,7 @@ int Tabbar::indexOf(const QString &filePath)
 
 QString Tabbar::currentName() const
 {
-    return DTabBar::tabText(currentIndex());
+    return textAt(currentIndex());
 }
 
 QString Tabbar::currentPath() const
@@ -301,7 +311,18 @@ QString Tabbar::fileAt(int index) const
 
 QString Tabbar::textAt(int index) const
 {
-    return DTabBar::tabText(index);
+    // 获取显示文本时恢复设置的助记符 '&'
+    return restoreMnemonic(DTabBar::tabText(index));
+}
+
+/**
+ * @brief 设置索引 \a index 指向标签页显示文本为 \a text
+ */
+void Tabbar::setTabText(int index, const QString &text)
+{
+    // 替换助记符
+    QString tmp = replaceMnemonic(text);
+    DTabBar::setTabText(index, tmp);
 }
 
 void Tabbar::setTabPalette(const QString &activeColor, const QString &highlightColor)
@@ -725,15 +746,21 @@ void Tabbar::showTabs()
 
 void Tabbar::handleTabReleased(int index)
 {
-    //qDebug() << "handleTabReleased" << index;
     if (index == -1) index = 0;
     QString path = m_listOldTabPath.value(index);
+    if (path.isEmpty()) {
+        return;
+    }
+
     int newIndex = m_tabPaths.indexOf(path);
     const QString tabPath = fileAt(newIndex);
     const QString tabName = textAt(newIndex);
 
     Window *window = static_cast<Window *>(this->window());
     EditWrapper *wrapper = window->wrapper(tabPath);
+    if (!wrapper) {
+        return;
+    }
 
     StartManager::instance()->createWindowFromWrapper(tabName, tabPath, wrapper->textEditor()->getTruePath(), wrapper, wrapper->isModified());
 
