@@ -1,32 +1,17 @@
-/*
-* Copyright (C) 2019 ~ 2021 Uniontech Software Technology Co.,Ltd.
-*
-* Author:     liangweidong <liangweidong@uniontech.com>
-*
-* Maintainer: liangweidong <liangweidong@uniontech.com>
-*
-* This program is free software: you can redistribute it and/or modify
-* it under the terms of the GNU General Public License as published by
-* the Free Software Foundation, either version 3 of the License, or
-* any later version.
-*
-* This program is distributed in the hope that it will be useful,
-* but WITHOUT ANY WARRANTY; without even the implied warranty of
-* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-* GNU General Public License for more details.
-*
-* You should have received a copy of the GNU General Public License
-* along with this program.  If not, see <http://www.gnu.org/licenses/>.
-*/
+// SPDX-FileCopyrightText: 2019 - 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
 
 #include "deletetextundocommand.h"
 #include "editwrapper.h"
 #include <QDebug>
 #include <QTextBlock>
 
-DeleteTextUndoCommand::DeleteTextUndoCommand(QTextCursor textcursor, QUndoCommand *parent)
+DeleteTextUndoCommand::DeleteTextUndoCommand(QTextCursor textcursor, QPlainTextEdit* edit, QUndoCommand *parent)
     : QUndoCommand(parent)
+    , m_edit(edit)
     , m_textCursor(textcursor)
+    , m_beginPos(m_textCursor.position())
 {
     if(m_textCursor.hasSelection()){
         m_sInsertText = m_textCursor.selectedText();
@@ -42,9 +27,11 @@ DeleteTextUndoCommand::DeleteTextUndoCommand(QTextCursor textcursor, QUndoComman
     }
 }
 
-DeleteTextUndoCommand::DeleteTextUndoCommand(QList<QTextEdit::ExtraSelection> &selections, QUndoCommand *parent)
+DeleteTextUndoCommand::DeleteTextUndoCommand(QList<QTextEdit::ExtraSelection> &selections, QPlainTextEdit *edit, QUndoCommand *parent)
     : QUndoCommand(parent)
+    , m_edit(edit)
     , m_ColumnEditSelections(selections)
+    , m_beginPos(m_textCursor.position())
 {
     int cnt = m_ColumnEditSelections.size();
     for (int i = 0; i < cnt; i++) {
@@ -68,15 +55,25 @@ DeleteTextUndoCommand::DeleteTextUndoCommand(QList<QTextEdit::ExtraSelection> &s
 void DeleteTextUndoCommand::undo()
 {
     if(m_ColumnEditSelections.isEmpty()){
+        // 插入前将光标恢复到删除前位置
+        m_textCursor.setPosition(m_beginPos);
         m_textCursor.insertText(m_sInsertText);
         m_textCursor.movePosition(QTextCursor::Left,QTextCursor::KeepAnchor,m_sInsertText.length());
 
+        // 进行撤销/恢复时将光标移动到撤销位置
+        if (m_edit) {
+            m_edit->setTextCursor(m_textCursor);
+        }
     }else {
         int cnt = m_ColumnEditSelections.size();
         for (int i = 0; i < cnt; i++) {
             m_ColumnEditSelections[i].cursor.insertText(m_selectTextList[i]);
             m_ColumnEditSelections[i].cursor.movePosition(QTextCursor::Left,QTextCursor::KeepAnchor,m_selectTextList[i].length());
         }
+
+        if (m_edit && !m_ColumnEditSelections.isEmpty()) {
+            m_edit->setTextCursor(m_ColumnEditSelections.last().cursor);
+        }
     }
 
 }
@@ -86,11 +83,20 @@ void DeleteTextUndoCommand::redo()
 {
     if (m_ColumnEditSelections.isEmpty()) {
         m_textCursor.deletePreviousChar();
+
+        // 进行撤销/恢复时将光标移动到撤销位置
+        if (m_edit) {
+            m_edit->setTextCursor(m_textCursor);
+        }
     }else {
         int cnt = m_ColumnEditSelections.size();
         for (int i = 0; i < cnt; i++) {
             m_ColumnEditSelections[i].cursor.deletePreviousChar();
         }
+
+        if (m_edit && !m_ColumnEditSelections.isEmpty()) {
+            m_edit->setTextCursor(m_ColumnEditSelections.last().cursor);
+        }
     }
 }
 
@@ -177,11 +183,15 @@ void DeleteTextUndoCommand2::redo()
         m_sInsertText = m_textCursor.selectedText();
         m_beginPostion = m_textCursor.selectionStart();
         m_textCursor.deletePreviousChar();
+
+        // 进行撤销/恢复时将光标移动到撤销位置
+        m_edit->setTextCursor(m_textCursor);
     }else {
         int cnt = m_ColumnEditSelections.size();
         for (int i = 0; i < cnt; i++) {
             m_beginPostion = m_ColumnEditSelections[i].cursor.selectionStart();
             m_ColumnEditSelections[i].cursor.deletePreviousChar();
+            m_edit->setTextCursor(m_ColumnEditSelections[i].cursor);
         }
     }
 }
