@@ -1,24 +1,6 @@
-﻿/* -*- Mode: C++; indent-tabs-mode: nil; tab-width: 4 -*-
-* -*- coding: utf-8 -*-
-*
-* Copyright (C) 2011 ~ 2018 Deepin, Inc.
-*
-* Author:     Wang Yong <wangyong@deepin.com>
-* Maintainer: Rekols    <rekols@foxmail.com>
-*
-* This program is free software: you can redistribute it and/or modify
-* it under the terms of the GNU General Public License as published by
-* the Free Software Foundation, either version 3 of the License, or
-* any later version.
-*
-* This program is distributed in the hope that it will be useful,
-* but WITHOUT ANY WARRANTY; without even the implied warranty of
-* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-* GNU General Public License for more details.
-*
-* You should have received a copy of the GNU General Public License
-* along with this program.  If not, see <http://www.gnu.org/licenses/>.
-*/
+﻿// SPDX-FileCopyrightText: 2011-2023 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
 
 #ifndef TEXTEDIT_H
 #define TEXTEDIT_H
@@ -33,6 +15,7 @@
 //添加自定义撤销重做栈
 #include "inserttextundocommand.h"
 #include "deletetextundocommand.h"
+#include "../widgets/bottombar.h"
 #include <QUndoStack>
 
 #include <KSyntaxHighlighting/Definition>
@@ -105,8 +88,6 @@ public:
     TextEdit(QWidget *parent = nullptr);
     ~TextEdit() override;
 
-    //在光标处添加删除内容
-
     //直接插入文本
     void insertTextEx(QTextCursor, QString);
     //同时插入多个位置的文本
@@ -136,25 +117,18 @@ public:
     void popRightMenu(QPoint pos = QPoint());
     //
     void setWrapper(EditWrapper *);
-
     EditWrapper *getWrapper();
 
-    /**
-     * @brief getFilePath 获取打开文件路径
-     * @return 打开文件路径
-     */
+    // 获取打开文件路径
     inline QString getFilePath() { return m_sFilePath;}
-    //
-    inline void setFilePath(QString file) { m_sFilePath = file;}
-    //
+    // 设置文件路径
+    inline void setFilePath(const QString &file) { m_sFilePath = file;}
+    // 取得左侧的导航控件，包含行号、书签、折叠控件等
     inline LeftAreaTextEdit *getLeftAreaWidget() { return m_pLeftAreaWidget;}
-    /**
-     * @brief 是否撤销重做操作
-     */
+
+    // 是否允许撤销重做操作
     bool isUndoRedoOpt();
-    /**
-     * @brief 判断文档是否被修改
-     */
+    // 判断文档是否被修改
     bool getModified();
 
     int getCurrentLine();
@@ -201,9 +175,7 @@ public:
     //剪切选中行或当前行至剪贴板中
     void cutlines();
 
-    /**
-     * @brief joinLines 合并行
-     */
+    // joinLines 合并行
     void joinLines();
 
     void killLine();
@@ -222,7 +194,7 @@ public:
 
     void setLineWrapMode(bool enable);
     void setFontFamily(QString fontName);
-    void setFontSize(int fontSize);
+    void setFontSize(qreal fontSize);
     void updateFont();
 
     void replaceAll(const QString &replaceText, const QString &withText);
@@ -256,10 +228,7 @@ public:
     // 手动更新所有的标记信息，用于撤销栈处理更新当前颜色标记操作
     void manualUpdateAllMark(const QList<QPair<MarkOperation, qint64> > &markInfo);
 
-    /**
-     * @author shaoyu.guo ut000455
-     * @brief updateMarkAllSelectColor 文档篇幅视图有变更时（翻页/滚动条变化/鼠标滚轮变化/键盘上下键），动态更新绘制可视范围内字符颜色
-     */
+    // 文档篇幅视图有变更时（翻页/滚动条变化/鼠标滚轮变化/键盘上下键），动态更新绘制可视范围内字符颜色
     void updateMarkAllSelectColor();
 
     void lineNumberAreaPaintEvent(QPaintEvent *event);
@@ -281,7 +250,7 @@ public:
     void completionWord(QString word);
     QString getWordAtMouse();
     QString getWordAtCursor();
-    void toggleReadOnlyMode();
+    void toggleReadOnlyMode(bool notNotify = false);
     void toggleComment(bool bValue);
     int getNextWordPosition(QTextCursor &cursor, QTextCursor::MoveMode moveMode);
     int getPrevWordPosition(QTextCursor cursor, QTextCursor::MoveMode moveMode);
@@ -578,9 +547,16 @@ public slots:
 
     void redo_();
     void undo_();
-    void moveText(int from, int to, const QString &text);
+
+    void moveText(int from, int to, const QString& text, bool copy = false);
     QTextCursor findCursor(const QString &substr, const QString &text, int from, bool backward = false, int cursorPos = 0);
+    void onPressedLineNumber(const QPoint& point);
     QString selectedText();
+    void onEndlineFormatChanged(BottomBar::EndlineFormat from,BottomBar::EndlineFormat to);
+
+    // 当前程序调色板更新时重绘部分组件
+    void onAppPaletteChanged();
+
 protected:
     bool event(QEvent *evt) override;   //触摸屏event事件
     void dragEnterEvent(QDragEnterEvent *event) override;
@@ -628,6 +604,12 @@ private:
     // 计算颜色标记替换信息列表
     void calcMarkReplaceList(QList<TextEdit::MarkReplaceInfo> &replaceList, const QString &oldText,
                              const QString &replaceText, const QString &withText, int offset = 0) const;
+    // 查找行号line起始的折叠区域
+    bool findFoldBlock(int line, QTextBlock &beginBlock, QTextBlock &endBlock, QTextBlock &curBlock);
+
+private slots:
+    // 文档内容变更时触发
+    void onTextContentChanged(int from, int charsRemoved, int charsAdded);
 
 public:
     int getFirstVisibleBlockId() const;
@@ -751,7 +733,7 @@ private:
     int m_cursorWidthChangeDelay = 2000;
     bool m_bReadOnlyPermission = false;
 
-    int m_fontSize = 16;
+    qreal m_fontSize = 16;
     QString m_fontName;
 
     Comment::CommentDefinition m_commentDefinition;
@@ -875,5 +857,7 @@ private:
     bool m_Permission2 = false;
     //左边栏更新标记
     UpdateOperationType m_LeftAreaUpdateState;
+
+    bool m_MidButtonPatse = false;      // 鼠标中键黏贴处理
 };
 #endif
