@@ -1,24 +1,11 @@
-/*
- * Copyright (C) 2017 ~ 2018 Deepin Technology Co., Ltd.
- *
- * Author:     rekols <rekols@foxmail.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+// SPDX-FileCopyrightText: 2017 - 2023 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
+
 #include "../widgets/window.h"
 #include "../encodes/detectcode.h"
 #include "../common/fileloadthread.h"
+#include "../widgets/pathsettintwgt.h"
 #include "editwrapper.h"
 #include "../common/utils.h"
 #include "leftareaoftextedit.h"
@@ -172,31 +159,45 @@ void EditWrapper::openFile(const QString &filepath, QString qstrTruePath, bool b
     // update file path.
     updatePath(filepath, qstrTruePath);
     m_pTextEdit->setIsFileOpen();
+    // 设置预处理标识位
+    m_bHasPreProcess = false;
+
+    if (!bIsTemFile && !isDraftFile()) {
+        Settings::instance()->setSavePath(PathSettingWgt::LastOptBox, QFileInfo(qstrTruePath).absolutePath());
+        Settings::instance()->setSavePath(PathSettingWgt::CurFileBox, QFileInfo(qstrTruePath).absolutePath());
+    }
 
     FileLoadThread *thread = new FileLoadThread(filepath);
     // begin to load the file.
+    connect(thread, &FileLoadThread::sigPreProcess, this, &EditWrapper::handleFilePreProcess);
     connect(thread, &FileLoadThread::sigLoadFinished, this, &EditWrapper::handleFileLoadFinished);
     connect(thread, &FileLoadThread::finished, thread, &FileLoadThread::deleteLater);
     thread->start();
 }
 
+/**
+ * @brief 按文件编码 \a encode 读取当前文件数据，若文件存在异常，则返回读取失败。
+ *      \a encode 可缺省，按文件默认编码读取。
+ * @param encode 文件编码
+ * @return 是否成功读取文件数据
+ */
 bool EditWrapper::readFile(QByteArray encode)
 {
-    QByteArray newEncode = encode;
-    if (newEncode.isEmpty()) {
-        newEncode = DetectCode::GetFileEncodingFormat(m_pTextEdit->getFilePath());
-        m_sFirstEncode = newEncode;
-    }
+    QFile file(m_pTextEdit->getTruePath());
+    if (file.open(QIODevice::ReadOnly)) {
+        QByteArray fileContent = file.readAll();
+        QByteArray newEncode = encode;
+        if (newEncode.isEmpty()) {
+            // 接口修改，补充文件头内容，最多读取1MB文件头数据
+            newEncode = DetectCode::GetFileEncodingFormat(
+                            m_pTextEdit->getFilePath(), fileContent.left(DATA_SIZE_1024 * DATA_SIZE_1024));
+            m_sFirstEncode = newEncode;
+        }
 
-    //QFile file(m_pTextEdit->getFilePath());
-    QFile file2(m_pTextEdit->getTruePath());
-
-    if (file2.open(QIODevice::ReadOnly)) {
-        QByteArray fileContent = file2.readAll();
         QByteArray Outdata;
         DetectCode::ChangeFileEncodingFormat(fileContent, Outdata, newEncode, QString("UTF-8"));
         loadContent(Outdata);
-        file2.close();
+        file.close();
         m_sCurEncode = newEncode;
         updateModifyStatus(false);
         return true;
@@ -204,13 +205,25 @@ bool EditWrapper::readFile(QByteArray encode)
     return false;
 }
 
-bool EditWrapper::saveAsFile(const QString &newFilePath, QByteArray encodeName)
+/**
+ * @brief 将当前文件内容按编码格式 \a encodeName 保存到指定路径 \a newFilePath
+ * @param newFilePath 另存的文件路径
+ * @param encodeName 文件保存时指定的文件格式
+ * @return 是否成功另存文件
+ */
+bool EditWrapper::saveAsFile(const QString &newFilePath, const QByteArray &encodeName)
 {
     // use QSaveFile for safely save files.
     QSaveFile saveFile(newFilePath);
     saveFile.setDirectWriteFallback(true);
 
     if (!saveFile.open(QIODevice::WriteOnly | QIODevice::Truncate)) {
+        qWarning() << Q_FUNC_INFO << "Open save file path error, " << saveFile.errorString();
+        QWidget *curWidget = this->window()->getStackedWgt()->currentWidget();
+        if (curWidget) {
+            DMessageManager::instance()->sendMessage(curWidget, QIcon(":/images/warning.svg"),
+                                                     QString(tr("You do not have permission to save %1")).arg(saveFile.fileName()));
+        }
         return false;
     }
 
@@ -220,11 +233,40 @@ bool EditWrapper::saveAsFile(const QString &newFilePath, QByteArray encodeName)
     }
 
     //auto append new line char to end of file when file's format is Linux/MacOS
-    QByteArray fileContent = m_pTextEdit->toPlainText().toUtf8();
+    QByteArray fileContent;
+    getPlainTextContent(fileContent);
 
     QByteArray Outdata;
-    DetectCode::ChangeFileEncodingFormat(fileContent, Outdata, QString("UTF-8"), encodeName);
-    file.write(Outdata);
+    bool convertSucc = DetectCode::ChangeFileEncodingFormat(fileContent, Outdata, QString("UTF-8"), encodeName);
+
+    // 转换存在异常
+    if (!convertSucc) {
+        qWarning() << QString("iconv Encode Transformat from '%1' to '%2' Fail! start QTextCodec Encode Transformat.")
+                      .arg(QString("UTF-8")).arg(m_sCurEncode);
+        // 使用 QTextCodec 进行转换尝试
+        QTextCodec *codec = QTextCodec::codecForName(encodeName);
+        if (codec) {
+            QByteArray encodedString = codec->fromUnicode(fileContent);
+            if (encodedString.isEmpty()) {
+                qWarning() << qPrintable("Both iconv and QTextCodec Encode Transformat Fail!");
+            } else {
+                qInfo() << QString("QTextCodec Encode Transformat from '%1' to '%2' Success!")
+                           .arg(QString("UTF-8")).arg(m_sCurEncode);
+
+                Outdata = encodedString;
+                convertSucc = true;
+            }
+
+        } else {
+            qWarning() << qPrintable("Unsupported QTextCodec Encode") << m_sCurEncode;
+        }
+    }
+
+    if (!Outdata.isEmpty()) {
+        // 如果新数据为空，不进行文件写入，以降低文件内容损失
+        file.write(Outdata);
+    }
+
     // close and delete file.
     QFileDevice::FileError error = file.error();
     file.close();
@@ -241,9 +283,7 @@ bool EditWrapper::saveAsFile(const QString &newFilePath, QByteArray encodeName)
 
     // did save work?
     // only finalize if stream status == OK
-    bool ok = (error == QFileDevice::NoError);
-
-    return ok;
+    return convertSucc && (error == QFileDevice::NoError);
 }
 
 bool EditWrapper::saveAsFile()
@@ -254,9 +294,7 @@ bool EditWrapper::saveAsFile()
     dialog.setDirectory(QDir::homePath());
     dialog.setNameFilter("*.txt");
 
-    //this->setUpdatesEnabled(false);
     int mode =  dialog.exec();
-    //this->setUpdatesEnabled(true);
     hideWarningNotices();
 
     if (QDialog::Accepted == mode) {
@@ -270,7 +308,7 @@ bool EditWrapper::saveAsFile()
             return false;
         }
 
-        // 以新的编码保存内容到文件
+        // 以新的编码保存内容到文件，无论何种格式，展示的文本编码为UTF-8
         QByteArray inputData = m_pTextEdit->toPlainText().toUtf8();
         QByteArray outData;
         DetectCode::ChangeFileEncodingFormat(inputData, outData, QString("UTF-8"), m_sFirstEncode);
@@ -283,6 +321,11 @@ bool EditWrapper::saveAsFile()
     return false;
 }
 
+/**
+ * @brief 按文件编码 \a encode 重新加载文件，并返回是否加载成功。文件有变更会提示是否保存。
+ * @param encode 文件编码
+ * @return 返回是否加载成功
+ */
 bool EditWrapper::reloadFileEncode(QByteArray encode)
 {
     //切换编码相同不重写加载
@@ -330,16 +373,30 @@ bool EditWrapper::reloadFileEncode(QByteArray encode)
 
         //保存
         if (res == 1) {
+            // 保存文件前缓存当前文件的编码格式，文件将按之前的编码格式保存
+            QString tempEncode = m_sCurEncode;
+
             //草稿文件
+            bool reloadSucc = false;
             if (Utils::isDraftFile(m_pTextEdit->getFilePath())) {
-                if (saveDraftFile()) {
-                    return readFile(encode);
-                } else {
-                    return false;
+                QString newFilePath;
+                if (saveDraftFile(newFilePath)) {
+                    reloadSucc = readFile(encode);
                 }
             } else {
-                return (saveFile() && readFile(encode));
+                if (this->window()->saveAsFile()) {
+                    reloadSucc = readFile(encode);
+                }
             }
+
+            if (reloadSucc) {
+                // 保存成功，更新编码格式
+                m_pBottomBar->setEncodeName(encode);
+            } else {
+                // 未成功保存，复位编码格式
+                m_sCurEncode = tempEncode;
+            }
+            return reloadSucc;
         }
 
         return false;
@@ -348,6 +405,65 @@ bool EditWrapper::reloadFileEncode(QByteArray encode)
     }
 }
 
+/**
+ * @brief 根据高亮格式文件的名称 \a definitionName 查询高亮格式配置，并格式化文档。
+ *      若未查找到格式，例如“None”，则移除高亮效果。
+ * @param definitionName 高亮格式文件名称
+ */
+void EditWrapper::reloadFileHighlight(QString definitionName)
+{
+    m_Definition = m_Repository.definitionForName(definitionName);
+    if (m_Definition.isValid() && !m_Definition.filePath().isEmpty()) {
+        if (!m_pSyntaxHighlighter) m_pSyntaxHighlighter = new CSyntaxHighlighter(m_pTextEdit->document());
+        QString m_themePath = Settings::instance()->settings->option("advance.editor.theme")->value().toString();
+        if (m_themePath.contains("dark")) {
+            m_pSyntaxHighlighter->setTheme(m_Repository.defaultTheme(KSyntaxHighlighting::Repository::DarkTheme));
+        } else {
+            m_pSyntaxHighlighter->setTheme(m_Repository.defaultTheme(KSyntaxHighlighting::Repository::LightTheme));
+        }
+        if (m_pSyntaxHighlighter) m_pSyntaxHighlighter->setDefinition(m_Definition);;
+        m_pTextEdit->setSyntaxDefinition(m_Definition);
+
+        // 获取当前展示区域文本块
+        QPoint startPoint = QPoint(0, 0);
+        QTextBlock beginBlock = m_pTextEdit->cursorForPosition(startPoint).block();
+        QTextBlock endBlock;
+
+        QScrollBar *pScrollBar = m_pTextEdit->verticalScrollBar();
+        if (pScrollBar->maximum() > 0) {
+            QPoint endPoint = QPointF(0, 1.5 * m_pTextEdit->height()).toPoint();
+            endBlock = m_pTextEdit->cursorForPosition(endPoint).block();
+        } else {
+            endBlock = m_pTextEdit->document()->lastBlock();
+        }
+
+        // 移除当前页面旧的高亮内容
+        QTextCursor cursor(beginBlock);
+        cursor.beginEditBlock();
+        for (QTextBlock var = beginBlock; var.isValid(); var = var.next()) {
+            var.layout()->clearFormats();
+            if (var == endBlock) {
+                break;
+            }
+        }
+        cursor.endEditBlock();
+        // 复位标识位
+        m_bHighlighterAll = false;
+
+        // 重新高亮当前界面
+        OnUpdateHighlighter();
+    } else {
+        // 不允许的高亮格式或无对应的高亮格式文件，例如“None”，移除高亮效果
+        m_bHighlighterAll = false;
+        m_Definition = KSyntaxHighlighting::Definition();
+        if (m_pSyntaxHighlighter) {
+            m_pSyntaxHighlighter->deleteLater();
+            m_pSyntaxHighlighter = nullptr;
+        }
+        m_pTextEdit->setSyntaxDefinition(m_Definition);
+    }
+}
+
 void EditWrapper::reloadModifyFile()
 {
     hideWarningNotices();
@@ -387,11 +503,12 @@ void EditWrapper::reloadModifyFile()
         if (res == 2) {
             //临时文件保存另存为 需要删除源草稿文件文件
             if (Utils::isDraftFile(m_pTextEdit->getFilePath())) {
-                if (!saveDraftFile()) {
+                QString newFilePath;
+                if (!saveDraftFile(newFilePath)) {
                     return;
                 }
             } else {
-                if (!saveAsFile()) {
+                if (!this->window()->saveAsFile()) {
                     return;
                 }
             }
@@ -420,7 +537,13 @@ QString EditWrapper::getTextEncode()
     return m_sCurEncode;
 }
 
-bool EditWrapper::saveFile()
+/**
+ * @brief 保存当前文件数据，若设置了特定的编码格式 \a encode , 则按此编码格式存储，
+ *      否则使用当前显示的文本编码。
+ * @param encode 文件编码
+ * @return 是否成功保存文件数据
+ */
+bool EditWrapper::saveFile(QByteArray encode)
 {
     QString qstrFilePath = m_pTextEdit->getTruePath();
     QFile file(qstrFilePath);
@@ -429,24 +552,35 @@ bool EditWrapper::saveFile()
     if (file.open(QIODevice::WriteOnly | QIODevice::Truncate)) {
         QByteArray fileContent;
         getPlainTextContent(fileContent);
+
+        if (!encode.isEmpty()) {
+            m_sCurEncode = encode;
+            // 更新底栏编码格式
+            m_pBottomBar->setEncodeName(encode);
+        }
+
         if (!fileContent.isEmpty()) {
             QByteArray Outdata;
             DetectCode::ChangeFileEncodingFormat(fileContent, Outdata, QString("UTF-8"), m_sCurEncode);
             // 如果 iconv 转换错误
-            if (Outdata.size() == 0) {
-                qWarning() << QString("iconv Encode Transformat from '%1' to '%2' Fail!")
-                           .arg(QString("UTF-8")).arg(m_sCurEncode)
-                           << ", start QTextCodec Encode Transformat.";
+            if (Outdata.isEmpty()) {
+                qWarning() << qPrintable(QString("iconv Encode Transformat from '%1' to '%2' Fail! start QTextCodec Encode Transformat.")
+                                         .arg(QString("UTF-8")).arg(m_sCurEncode));
                 // 使用 QTextCodec 进行转换尝试
                 QTextCodec *codec = QTextCodec::codecForName(m_sCurEncode.toUtf8());
-                QByteArray encodedString = codec->fromUnicode(fileContent);
+                if (codec) {
+                    QByteArray encodedString = codec->fromUnicode(fileContent);
+
+                    if (encodedString.isEmpty()) {
+                        qWarning() << qPrintable("Both iconv and QTextCodec Encode Transformat Fail!");
+                    } else {
+                        qWarning() << qPrintable(QString("QTextCodec Encode Transformat from '%1' to '%2' Success!")
+                                                 .arg(QString("UTF-8")).arg(m_sCurEncode));
+                        Outdata = encodedString;
+                    }
 
-                if (encodedString.isEmpty()) {
-                    qWarning() << "Both iconv and QTextCodec Encode Transformat Fail!";
                 } else {
-                    qWarning() << QString("QTextCodec Encode Transformat from '%1' to '%2' Success!")
-                               .arg(QString("UTF-8")).arg(m_sCurEncode);
-                    Outdata = encodedString;
+                    qWarning() << qPrintable("Unsupported QTextCodec format:") << m_sCurEncode;
                 }
             }
 
@@ -500,6 +634,10 @@ bool EditWrapper::saveFile()
 void EditWrapper::getPlainTextContent(QByteArray &plainTextContent)
 {
     QString strPlainText = m_pTextEdit->toPlainText();
+    if (BottomBar::EndlineFormat::Windows == m_pBottomBar->getEndlineFormat()) {
+        strPlainText.replace("\n", "\r\n");
+    }
+
     qint64 iPlainTextAllLen = strPlainText.length();
     qint64 iStep = 300 * DATA_SIZE_1024 * DATA_SIZE_1024;
     /* qt开发分析结论：大文本情况下toLocal8Bit()转换会引起应用闪退，此闪退问题qt方无法处理 */
@@ -526,6 +664,11 @@ void EditWrapper::getPlainTextContent(QByteArray &plainTextContent)
     }
 }
 
+/**
+ * @brief saveTemFile 保存备份文件
+ * @param qstrDir　备份文件路径
+ * @return true or false
+ */
 bool EditWrapper::saveTemFile(QString qstrDir)
 {
     QFile file(qstrDir);
@@ -617,14 +760,26 @@ bool EditWrapper::isTemFile()
     return m_bIsTemFile;
 }
 
-bool EditWrapper::saveDraftFile()
+/**
+ * @brief 保存草稿文件，若保存成功，新文件路径通过 \a newFilePath 返回，
+ *      且对应标签页已更新为新的文件信息。
+ * @param newFilePath 保存的新文件路径
+ * @return 是否保存成功
+ */
+bool EditWrapper::saveDraftFile(QString &newFilePath)
 {
     DFileDialog dialog(this, tr("Save"));
     dialog.setAcceptMode(QFileDialog::AcceptSave);
-    dialog.addComboBox(QObject::tr("Encoding"),  QStringList() << m_sCurEncode);
     dialog.setDirectory(QDir::homePath());
     dialog.setNameFilter("*.txt");
 
+    // 允许选取保存的编码格式
+    DFileDialog::DComboBoxOptions encodingOptions;
+    encodingOptions.editable = false;
+    encodingOptions.defaultValue = getTextEncode();
+    encodingOptions.data = Utils::getSupportEncodingList();
+    dialog.addComboBox(QObject::tr("Encoding"), encodingOptions);
+
     if (m_pWindow) {
         m_pWindow = this->window();
         QRegularExpression reg("[^*](.+)");
@@ -632,13 +787,12 @@ bool EditWrapper::saveDraftFile()
         dialog.selectFile(match.captured(0) + ".txt");
     }
 
-    //this->setUpdatesEnabled(false);
     int mode =  dialog.exec(); // 0表示取消 1保存
-    // this->setUpdatesEnabled(true);
     hideWarningNotices();
 
     if (mode == 1) {
-        const QString newFilePath = dialog.selectedFiles().value(0);
+        const QByteArray encode = dialog.getComboBoxValue(QObject::tr("Encoding")).toUtf8();
+        newFilePath = dialog.selectedFiles().value(0);
         if (newFilePath.isEmpty())
             return false;
 
@@ -651,7 +805,7 @@ bool EditWrapper::saveDraftFile()
         // 以新的编码保存内容到文件
         QByteArray inputData = m_pTextEdit->toPlainText().toUtf8();
         QByteArray outData;
-        DetectCode::ChangeFileEncodingFormat(inputData, outData, QString("UTF-8"), m_sCurEncode);
+        DetectCode::ChangeFileEncodingFormat(inputData, outData, QString("UTF-8"), encode);
         qfile.write(outData);
         qfile.close();
 
@@ -729,64 +883,89 @@ void EditWrapper::handleCursorModeChanged(TextEdit::CursorMode mode)
     }
 }
 
-void EditWrapper::handleFileLoadFinished(const QByteArray &encode, const QByteArray &content)
+/**
+ * @brief 处理文件预加载服务
+ * @param encode    文件编码
+ * @param content   文件内容，不超过1MB
+ *
+ * @note 预加载的数据量较小(1MB)，且可能分割字符，在文件完成读取后，预加载的数据将被清空并重新加载完整文档。
+ */
+void EditWrapper::handleFilePreProcess(const QByteArray &encode, const QByteArray &content)
 {
-    m_Definition = m_Repository.definitionForFileName(m_pTextEdit->getFilePath());
-    if (m_Definition.isValid() && !m_Definition.filePath().isEmpty()) {
-        if (!m_pSyntaxHighlighter) m_pSyntaxHighlighter = new CSyntaxHighlighter(m_pTextEdit->document());
-        QString m_themePath = Settings::instance()->settings->option("advance.editor.theme")->value().toString();
-        if (m_themePath.contains("dark")) {
-            m_pSyntaxHighlighter->setTheme(m_Repository.defaultTheme(KSyntaxHighlighting::Repository::DarkTheme));
-        } else {
-            m_pSyntaxHighlighter->setTheme(m_Repository.defaultTheme(KSyntaxHighlighting::Repository::LightTheme));
+    // 重新加载处理
+    reinitOnFileLoad(encode);
+    // 已进行预处理标识
+    m_bHasPreProcess = true;
+
+    // 设置界面交互效果
+    QApplication::setOverrideCursor(Qt::WaitCursor);
+    m_pTextEdit->clear();
+    m_pTextEdit->setLeftAreaUpdateState(TextEdit::FileOpenBegin);
+    QTextCursor cursor = m_pTextEdit->textCursor();
+
+    QTextCodec *codec = QTextCodec::codecForName("UTF-8");
+    if (!codec) {
+        qInfo() << "QTextCodec::codecForName \"UTF-8\" return nullptr";
+        return;
+    }
+
+    // 直接加载数据到文档页面
+    QString data = codec->toUnicode(content.constData(), content.size());
+    cursor.insertText(data);
+    // 界面语法高亮
+    OnUpdateHighlighter();
+
+    m_pTextEdit->setLeftAreaUpdateState(TextEdit::FileOpenEnd);
+    QApplication::restoreOverrideCursor();
+}
+
+/**
+ * @brief 处理文件加载完成服务，取得加载完成的所有文件数据，重新初始化界面
+ * @param encode    文件编码
+ * @param content   完整文件内容
+ */
+void EditWrapper::handleFileLoadFinished(const QByteArray &encode, const QByteArray &content, bool error)
+{
+    // 判断是否预加载，若已预加载，则无需重新初始化
+    if (!m_bHasPreProcess) {
+        reinitOnFileLoad(encode);
+    }
+
+    if (!error) {
+        bool flag = m_pTextEdit->getReadOnlyPermission();
+        if (flag == true) {
+            // note: 特殊处理，由于需要TextEdit处于可编辑状态追加文件数据，临时设置非只读状态
+            m_pTextEdit->setReadOnly(false);
         }
 
-        if (m_pSyntaxHighlighter) m_pSyntaxHighlighter->setDefinition(m_Definition);;
-        m_pTextEdit->setSyntaxDefinition(m_Definition);
-        m_pBottomBar->getHighlightMenu()->setCurrentTextOnly(m_Definition.translatedName());
+        m_bFileLoading = true;
+
+        //备份显示修改状态
+        if (m_bIsTemFile) {
+            updateModifyStatus(true);
+        }
+
+        // 判断处理前后对象状态
+        QPointer<QObject> checkPtr(this);
+        // 加载数据
+        loadContent(content);
+        if (checkPtr.isNull()) {
+            return;
+        }
+
+        m_bFileLoading = false;
+        if (flag == true) {
+            m_pTextEdit->setReadOnly(true);
+        }
+
+        if (m_bQuit) {
+            return;
+        }
+    } else {
+        // 清除之前读取的数据
+        m_pTextEdit->clear();
     }
 
-    if (!Utils::isDraftFile(m_pTextEdit->getFilePath())) {
-        DRecentData data;
-        data.appName = "Deepin Editor";
-        data.appExec = "deepin-editor";
-        DRecentManager::addItem(m_pTextEdit->getFilePath(), data);
-    }
-
-    bool flag = m_pTextEdit->getReadOnlyPermission();
-    if (flag == true) {
-        // note: 特殊处理，由于需要TextEdit处于可编辑状态追加文件数据，临时设置非只读状态
-        m_pTextEdit->setReadOnly(false);
-    }
-
-    m_bFileLoading = true;
-    m_sCurEncode = encode;
-    m_sFirstEncode = encode;
-
-    //备份显示修改状态
-    if (m_bIsTemFile) {
-        updateModifyStatus(true);
-    }
-
-    // 判断处理前后对象状态
-    QPointer<QObject> checkPtr(this);
-    // 加载数据
-    loadContent(content);
-    if (checkPtr.isNull()) {
-        return;
-    }
-
-    //先屏蔽，双字节空字符先按照显示字符编码号处理
-    //clearDoubleCharaterEncode();
-    //PerformanceMonitor::openFileFinish(filePath(), QFileInfo(filePath()).size());
-
-    m_bFileLoading = false;
-    if (flag == true) {
-        m_pTextEdit->setReadOnly(true);
-    }
-    if (m_bQuit) {
-        return;
-    }
     m_pTextEdit->setTextFinished();
 
     QStringList temFileList = Settings::instance()->settings->option("advance.editor.browsing_history_temfile")->value().toStringList();
@@ -806,17 +985,8 @@ void EditWrapper::handleFileLoadFinished(const QByteArray &encode, const QByteAr
                     QJsonValue localPathValue = object.value("localPath");  // 获取指定 key 对应的 value
                     QJsonValue temFilePathValue = object.value("temFilePath");  // 获取指定 key 对应的 value
 
-                    if (localPathValue.toString() == m_pTextEdit->getFilePath()) {
-                        QJsonValue value = object.value("cursorPosition");  // 获取指定 key 对应的 value
-
-                        if (value.isString()) {
-                            QTextCursor cursor = m_pTextEdit->textCursor();
-                            cursor.setPosition(value.toString().toInt());
-                            m_pTextEdit->setTextCursor(cursor);
-                            OnUpdateHighlighter();
-                            break;
-                        }
-                    } else if (temFilePathValue.toString() == m_pTextEdit->getFilePath()) {
+                    if (localPathValue.toString() == m_pTextEdit->getFilePath()
+                            || temFilePathValue.toString() == m_pTextEdit->getFilePath()) {
                         QJsonValue value = object.value("cursorPosition");  // 获取指定 key 对应的 value
 
                         if (value.isString()) {
@@ -831,6 +1001,7 @@ void EditWrapper::handleFileLoadFinished(const QByteArray &encode, const QByteAr
             }
         }
     }
+
     //备份显示修改状态
     if (m_bIsTemFile) {
         updateModifyStatus(true);
@@ -842,6 +1013,19 @@ void EditWrapper::handleFileLoadFinished(const QByteArray &encode, const QByteAr
     }
 
     m_pBottomBar->setEncodeName(m_sCurEncode);
+
+    // 提示读取错误信息
+    if (error) {
+        // 设置文本为只读模式，且不显示通知
+        if (!m_pTextEdit->getReadOnlyMode()) {
+            m_pTextEdit->toggleReadOnlyMode(true);
+        }
+
+        m_pWaringNotices->setMessage(tr("The file cannot be read, which may be too large or has been damaged!"));
+        m_pWaringNotices->clearBtn();
+        m_pWaringNotices->show();
+        DMessageManager::instance()->sendMessage(m_pTextEdit, m_pWaringNotices);
+    }
 }
 
 
@@ -879,7 +1063,7 @@ void EditWrapper::OnUpdateHighlighter()
 {
     if (m_pSyntaxHighlighter  && !m_bQuit && !m_bHighlighterAll) {
         QScrollBar *pScrollBar = m_pTextEdit->verticalScrollBar();
-        QPoint startPoint = QPointF(0, 0).toPoint();
+        QPoint startPoint = QPoint(0, 0);
         QTextBlock beginBlock = m_pTextEdit->cursorForPosition(startPoint).block();
         QTextBlock endBlock;
 
@@ -903,8 +1087,8 @@ void EditWrapper::OnUpdateHighlighter()
             // 判断是否此文本块为折叠区域起始的文本块，判断'{''}'处理
             QTextBlock prevBlock = endBlock;
             while (prevBlock.isValid()
-                   && !foundBrace
-                   && maxFindBlockNumber < prevBlock.blockNumber()) {
+                    && !foundBrace
+                    && maxFindBlockNumber < prevBlock.blockNumber()) {
                 // 逆序查询文本块数据，查找起始文本块
                 QString text = prevBlock.text();
                 for (int i = text.size() - 1; i >= 0; i--) {
@@ -1152,6 +1336,7 @@ void EditWrapper::loadContent(const QByteArray &strContent)
     int max = 40 * 1024 * 1024;
 
     QString data;
+    int inserted = 0;
 
     if (len > max) {
         // 当读取大文件时，采用事件队列方式处理
@@ -1191,11 +1376,17 @@ void EditWrapper::loadContent(const QByteArray &strContent)
             //秒开界面语法高亮
             OnUpdateHighlighter();
             QApplication::processEvents();
+            inserted += InitContentPos;
+            double progress = (inserted * 1.0) / len * 100;
+            m_pBottomBar->setProgress(static_cast<int>(progress));
             if (!m_bQuit) {
                 //data = strContent.mid(InitContentPos, len - InitContentPos);
                 QByteArray text = strContent.mid(InitContentPos, len - InitContentPos);
                 data = codec->toUnicode(text.constData(), text.size(), &state);
                 cursor.insertText(data);
+                inserted += (len - InitContentPos);
+                progress = (inserted * 1.0) / len * 100;
+                m_pBottomBar->setProgress(static_cast<int>(progress));
             }
         } else {
             if (!m_bQuit) {
@@ -1207,6 +1398,9 @@ void EditWrapper::loadContent(const QByteArray &strContent)
                 m_pTextEdit->setTextCursor(firstLineCursor);
                 //秒开界面语法高亮
                 OnUpdateHighlighter();
+                inserted += len;
+                double progress = (inserted * 1.0) / len * 100;
+                m_pBottomBar->setProgress(static_cast<int>(progress));
             }
         }
     }
@@ -1215,10 +1409,47 @@ void EditWrapper::loadContent(const QByteArray &strContent)
     }
     if (m_pBottomBar != nullptr) {
         m_pBottomBar->setChildEnabled(true);
+        auto format = BottomBar::getEndlineFormat(strContent);
+        m_pBottomBar->setEndlineMenuText(format);
     }
     m_pTextEdit->setReadOnly(false);
     m_pTextEdit->setLeftAreaUpdateState(TextEdit::FileOpenEnd);
     QApplication::restoreOverrideCursor();
+
+
+}
+
+/**
+ * @brief 文件加载时重新执行初始化，包括重置文件高亮配置、记录文件信息。
+ * @param encode 当前文件解析的编码
+ */
+void EditWrapper::reinitOnFileLoad(const QByteArray &encode)
+{
+    m_Definition = m_Repository.definitionForFileName(m_pTextEdit->getFilePath());
+    if (m_Definition.isValid() && !m_Definition.filePath().isEmpty()) {
+        if (!m_pSyntaxHighlighter) m_pSyntaxHighlighter = new CSyntaxHighlighter(m_pTextEdit->document());
+        QString m_themePath = Settings::instance()->settings->option("advance.editor.theme")->value().toString();
+        if (m_themePath.contains("dark")) {
+            m_pSyntaxHighlighter->setTheme(m_Repository.defaultTheme(KSyntaxHighlighting::Repository::DarkTheme));
+        } else {
+            m_pSyntaxHighlighter->setTheme(m_Repository.defaultTheme(KSyntaxHighlighting::Repository::LightTheme));
+        }
+
+        if (m_pSyntaxHighlighter) m_pSyntaxHighlighter->setDefinition(m_Definition);
+        m_pTextEdit->setSyntaxDefinition(m_Definition);
+        m_pBottomBar->getHighlightMenu()->setCurrentTextOnly(m_Definition.translatedName());
+    }
+
+    if (!Utils::isDraftFile(m_pTextEdit->getFilePath())) {
+        DRecentData data;
+        data.appName = "Deepin Editor";
+        data.appExec = "deepin-editor";
+        DRecentManager::addItem(m_pTextEdit->getFilePath(), data);
+    }
+
+    // 初始化设置编码
+    m_sCurEncode = encode;
+    m_sFirstEncode = encode;
 }
 
 void EditWrapper::clearDoubleCharaterEncode()
@@ -1232,5 +1463,3 @@ void EditWrapper::clearDoubleCharaterEncode()
         emit sigClearDoubleCharaterEncode();
     }
 }
-
-
