@@ -1,24 +1,6 @@
-/* -*- Mode: C++; indent-tabs-mode: nil; tab-width: 4 -*-
- * -*- coding: utf-8 -*-
- *
- * Copyright (C) 2011 ~ 2018 Deepin, Inc.
- *
- * Author:     Wang Yong <wangyong@deepin.com>
- * Maintainer: Rekols    <rekols@foxmail.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+// SPDX-FileCopyrightText: 2011-2023 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
 
 #ifndef WINDOW_H
 #define WINDOW_H
@@ -37,6 +19,7 @@
 #include "../common/performancemonitor.h"
 #include "../common/dbusinterface.h"
 #include "../common/iflytekaiassistantthread.h"
+#include "../common/CSyntaxHighlighter.h"
 #include <DMainWindow>
 #include <DStackedWidget>
 #include <qprintpreviewdialog.h>
@@ -49,6 +32,12 @@ class Window : public DMainWindow
     Q_OBJECT
 
 public:
+    // 打印文档信息，用于超大文档的打印
+    struct PrintInfo {
+        QTextDocument       *doc = nullptr;         // 打印的文本
+        CSyntaxHighlighter  *highlighter = nullptr; // 高亮处理
+    };
+
     explicit Window(DMainWindow *parent = nullptr);
     ~Window() override;
 
@@ -58,6 +47,15 @@ public:
      */
     void detectionIflytekaiassistant();
     bool getIsRegistIflytekAiassistant();
+    /**
+     * @brief 加载语音助手配置文件
+     */
+    void loadIflytekaiassistantConfig();
+    /**
+     * @brief 获取语音助手配置文件数据
+     * @param mode_name　接口模块名称
+     */
+    bool getIflytekaiassistantConfig(const QString &mode_name);
     //跟新文件修改状态
     void updateModifyStatus(const QString &path, bool isModified);
     //跟新tab文件名称
@@ -115,29 +113,19 @@ public:
     void remberPositionRestore();
 
     void displayShortcuts();
+    // 文本打印
     void doPrint(DPrinter *printer, const QVector<int> &pageRange);
+    // 大文本打印
+    void doPrintWithLargeDoc(DPrinter *printer, const QVector<int> &pageRange);
+    // 翻页预览打印，无需重新布局
     void asynPrint(QPainter &p, DPrinter *printer, const QVector<int> &pageRange);
 
-    /**
-     * @brief backupFile 备份文件
-     */
+    // 备份文件
     void backupFile();
-
-    /**
-     * @brief closeAllFiles 关闭当前窗口所有文件
-     * @return
-     */
+    // 关闭当前窗口所有文件
     bool closeAllFiles();
-
-    /**
-     * @brief addTemFileTab　恢复备份文件标签页
-     * @param qstrPath　打开文件路径
-     * @param qstrName　真实文件名
-     * @param qstrTruePath　真实文件路径
-     * @param qstrTruePath　最后一次修改时间
-     * @param bIsTemFile　是否修改
-     */
-    void addTemFileTab(QString qstrPath, QString qstrName, QString qstrTruePath, QString lastModifiedTime, bool bIsTemFile = false);
+    // 恢复备份文件标签页
+    void addTemFileTab(const QString &qstrPath, const QString &qstrName, const QString &qstrTruePath, const QString &lastModifiedTime, bool bIsTemFile = false);
 
     QMap<QString, EditWrapper *> getWrappers();
 
@@ -190,7 +178,7 @@ public slots:
     void slotReplacebarClose();
 
     void handleReplaceAll(const QString &replaceText, const QString &withText);
-    void handleReplaceNext(QString file, const QString &replaceText, const QString &withText);
+    void handleReplaceNext(const QString &file, const QString &replaceText, const QString &withText);
     void handleReplaceRest(const QString &replaceText, const QString &withText);
     void handleReplaceSkip(QString file, QString keyword);
 
@@ -215,7 +203,7 @@ public slots:
     void slotClearDoubleCharaterEncode();
     void slotSigThemeChanged(const QString &path);
     void slotSigAdjustFont(QString fontName);
-    void slotSigAdjustFontSize(int fontSize);
+    void slotSigAdjustFontSize(qreal fontSize);
     void slotSigAdjustTabSpaceNumber(int number);
     void slotSigAdjustWordWrap(bool enable);
     void slotSigSetLineNumberShow(bool bIsShow);
@@ -235,6 +223,21 @@ private:
     void updateThemePanelGeomerty();
     void checkTabbarForReload();
     void clearPrintTextDocument();
+    void setWindowTitleInfo();
+    // 取得当前文档打开路径（新建文档为"系统-文档"目录）
+    QString getCurrentOpenFilePath();
+    // 计算字体大小的缩放比例
+    qreal calcFontScale(qreal fontSize);
+    // 从字体缩放比例推算字体大小
+    qreal calcFontSizeFromScale(qreal fontScale);
+
+    // 克隆文本数据
+    bool cloneLargeDocument(EditWrapper *editWrapper);
+    // 打印多文本数据
+    void printPageWithMultiDoc(int index, QPainter *painter, const QVector<PrintInfo> &printInfo,
+                               const QRectF &body, const QRectF &pageCountBox);
+    // 重新更新文本
+    void rehighlightPrintDoc(QTextDocument *doc, CSyntaxHighlighter *highlighter);
 
 protected:
     void resizeEvent(QResizeEvent *event) override;
@@ -244,6 +247,8 @@ protected:
     void keyReleaseEvent(QKeyEvent *keyEvent) override;
     void dragEnterEvent(QDragEnterEvent *e) override;
     void dropEvent(QDropEvent *event) override;
+    // 处理延迟处理等定时器事件
+    void timerEvent(QTimerEvent *e) override;
 
 private:
     DBusDaemon::dbus *m_rootSaveDBus {nullptr};
@@ -273,7 +278,7 @@ private:
     QString m_blankFileDir;
     QString m_backupDir;
     QString m_autoBackupDir;
-    int m_fontSize = 0;
+    qreal m_fontSize = 0;
 
     QString m_titlebarStyleSheet;
 
@@ -288,14 +293,26 @@ private:
     QProcess *m_shortcutViewProcess = nullptr;
     bool m_needMoveToCenter = false;
     DPrintPreviewDialog *m_pPreview {nullptr};
+
     //打印文本
-    QTextDocument *m_printDoc = nullptr;
-    //打印布局
-    QPageLayout m_lastLayout;
-    //判断是否是新的打印文档
-    bool m_isNewPrint = false;
+    QTextDocument *m_printDoc = nullptr;            // 打印文档，用于普通文档打印
+    QPageLayout m_lastLayout;                       // 打印布局
+    bool m_isNewPrint = false;                      // 判断是否是新的打印文档
+    bool m_bLargePrint = false;                     // 是否为大文件打印
+    bool m_bPrintProcessing = false;                // 文件打印计算中
+    EditWrapper *m_printWrapper = nullptr;          // 当前处理的编辑对象(关闭标签页时需要退出打印)
+    QTextDocument *printCopyDoc = nullptr;              // 用于大文本打印时的拷贝文档
+    CSyntaxHighlighter *printCopyHighlighter = nullptr; // 用于大文本打印时的高亮文档
+    QVector<PrintInfo> m_printDocList;              // 打印文档列表，用于超大文档打印
+    int m_multiDocPageCount = 0;                    // 用于超大文档打印时单独记录多文档的打印页数
+
+    QBasicTimer m_delayCloseTabTimer;               // 延迟关闭标签页定时器，防止异常情况多次触发关闭同一标签页的情况
+    int m_requestCloseTabIndex = 0;                 // 请求关闭的标签页索引
+
     //语音助手服务是否被注册
     bool m_bIsRegistIflytekAiassistant {false};
+    //记录语音助手接口配置状态
+    QMap<QString, bool> m_IflytekAiassistantState;
 };
 
 #endif
