@@ -1,19 +1,7 @@
-/*
-* Copyright (C) 2019 ~ 2020 Deepin Technology Co., Ltd.
-*
-* Author:     liumaochuan <liumaochuan@uniontech.com>
-* Maintainer: liumaochuan <liumaochuan@uniontech.com>
-* This program is free software: you can redistribute it and/or modify
-* it under the terms of the GNU General Public License as published by
-* the Free Software Foundation, either version 3 of the License, or
-* any later version.
-* This program is distributed in the hope that it will be useful,
-* but WITHOUT ANY WARRANTY; without even the implied warranty of
-* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-* GNU General Public License for more details.
-* You should have received a copy of the GNU General Public License
-* along with this program.  If not, see <http://www.gnu.org/licenses/>.
-*/
+// SPDX-FileCopyrightText: 2019 - 2023 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
+
 #include "ut_utils.h"
 
 #include "../../src/common/settings.h"
@@ -541,4 +529,32 @@ TEST(UT_Utils_checkRegionIntersect, checkRegionIntersect)
     ASSERT_EQ(type, Utils::EIntersectInner);
 }
 
+QByteArray supportEncoding_readAll_stub()
+{
+    return QByteArray();
+}
 
+TEST(UT_Utils_getSupportEncoding, getSupportEncoding)
+{
+    auto encoding = Utils::getSupportEncoding();
+    ASSERT_FALSE(encoding.isEmpty());
+}
+
+TEST(UT_Utils_getSupportEncoding, getSupportEncodingWithError)
+{
+    Stub stub1;
+    typedef QVector<QPair<QString, QStringList> > VecType;
+    stub1.set(ADDR(VecType, isEmpty), supportEncoding_readAll_stub);
+    Stub stub2;
+    stub2.set(ADDR(QIODevice, readAll), supportEncoding_readAll_stub);
+
+    auto encoding = Utils::getSupportEncoding();
+    ASSERT_TRUE(encoding.isEmpty());
+}
+
+TEST(UT_Utils_getSupportEncodingList, getSupportEncodingList)
+{
+    QStringList encodingList = Utils::getSupportEncodingList();
+    ASSERT_FALSE(encodingList.isEmpty());
+    ASSERT_TRUE(encodingList.contains("UTF-8"));
+}
