@@ -1,19 +1,7 @@
-/*
-* Copyright (C) 2019 ~ 2020 Deepin Technology Co., Ltd.
-*
-* Author:     liumaochuan <liumaochuan@uniontech.com>
-* Maintainer: liumaochuan <liumaochuan@uniontech.com>
-* This program is free software: you can redistribute it and/or modify
-* it under the terms of the GNU General Public License as published by
-* the Free Software Foundation, either version 3 of the License, or
-* any later version.
-* This program is distributed in the hope that it will be useful,
-* but WITHOUT ANY WARRANTY; without even the implied warranty of
-* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-* GNU General Public License for more details.
-* You should have received a copy of the GNU General Public License
-* along with this program.  If not, see <http://www.gnu.org/licenses/>.
-*/
+// SPDX-FileCopyrightText: 2019 - 2023 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
+
 #include "ut_editwrapper.h"
 #include "qfile.h"
 #include <KSyntaxHighlighting/SyntaxHighlighter>
@@ -37,7 +25,7 @@ bool rettruestub()
     return true;
 }
 
-QStringList stringList = {"123","456"};
+QStringList stringList = {"/tmp/ut_123.txt","/tmp/ut_456.txt"};
 QStringList retstringliststub()
 {
     return stringList;
@@ -143,7 +131,6 @@ void hideWarningNotices_stub()
 //bool saveFile_001();
 TEST(UT_Editwrapper_saveFile, UT_Editwrapper_saveFile_001)
 {
-    /*
     Window *pWindow = new Window();
     pWindow->addBlankTab(QString());
     pWindow->currentWrapper()->textEditor()->insertTextEx(pWindow->currentWrapper()->textEditor()->textCursor(),
@@ -157,10 +144,9 @@ TEST(UT_Editwrapper_saveFile, UT_Editwrapper_saveFile_001)
         stub.set(pWindow->currentWrapper()->saveFile(), saveFile_001_stub());
         bRet = pWindow->currentWrapper()->saveFile();
     }
-    ASSERT_TRUE(bRet == true);
+    EXPECT_TRUE(bRet == true);
 
     pWindow->deleteLater();
-    */
 }
 
 bool saveFile_002_stub()
@@ -171,7 +157,6 @@ bool saveFile_002_stub()
 //bool saveFile_002();
 TEST(UT_Editwrapper_saveFile, UT_Editwrapper_saveFile_002)
 {
-    /*
     Window *pWindow = new Window();
     pWindow->addBlankTab(QString());
     bool bRet = pWindow->currentWrapper()->saveFile();
@@ -182,17 +167,14 @@ TEST(UT_Editwrapper_saveFile, UT_Editwrapper_saveFile_002)
         stub.set(pWindow->currentWrapper()->saveFile(), saveFile_002_stub());
         bRet = pWindow->currentWrapper()->saveFile();
     }
-    ASSERT_TRUE(bRet == true);
+    EXPECT_TRUE(bRet == true);
 
-    delete pWindow;
-    pWindow = nullptr;
-    */
+    pWindow->deleteLater();
 }
 
 //bool saveFile_003();
 TEST(UT_Editwrapper_saveFile, UT_Editwrapper_saveFile_003)
 {
-    /*
     Window *pWindow = new Window();
     pWindow->addBlankTab(QString());
     pWindow->currentWrapper()->textEditor()->m_sFilePath = QString("");
@@ -200,16 +182,13 @@ TEST(UT_Editwrapper_saveFile, UT_Editwrapper_saveFile_003)
     Stub stubNotices;
     stubNotices.set(ADDR(EditWrapper, hideWarningNotices), hideWarningNotices_stub);
     bool bRet = pWindow->currentWrapper()->saveFile();
-    ASSERT_TRUE(bRet == false);
+    EXPECT_TRUE(bRet == false);
 
-    delete pWindow;
-    pWindow = nullptr;
-    */
+    pWindow->deleteLater();
 }
 
 TEST(UT_Editwrapper_saveFile, UT_Editwrapper_saveFile_004)
 {
-    /*
     Window *pWindow = new Window();
     pWindow->addBlankTab(QString());
     pWindow->currentWrapper()->textEditor()->m_sFilePath = QString("");
@@ -226,15 +205,13 @@ TEST(UT_Editwrapper_saveFile, UT_Editwrapper_saveFile_004)
     s2.set(ADDR(QByteArray,isEmpty),rettruestub);
 
     bool bRet = pWindow->currentWrapper()->saveFile();
+    EXPECT_TRUE(bRet);
 
-    delete pWindow;
-    pWindow = nullptr;
-    */
+    pWindow->deleteLater();
 }
 
 TEST(UT_Editwrapper_saveFile, UT_Editwrapper_saveFile_005)
 {
-    /*
     Window *pWindow = new Window();
     pWindow->addBlankTab(QString());
     pWindow->currentWrapper()->textEditor()->m_sFilePath = QString("");
@@ -255,12 +232,52 @@ TEST(UT_Editwrapper_saveFile, UT_Editwrapper_saveFile_005)
 
     intvalue=0;
     bool bRet = pWindow->currentWrapper()->saveFile();
+    EXPECT_TRUE(bRet);
 
-    delete pWindow;
-    pWindow = nullptr;
-    */
+    pWindow->deleteLater();
 }
 
+
+TEST(UT_Editwrapper_saveFile, UT_Editwrapper_saveFile_with_encode)
+{
+    Window *pWindow = new Window;
+    pWindow->addBlankTab(QString());
+    QString tmpFilePath("/tmp/UT_Editwrapper_saveFile.txt");
+    pWindow->currentWrapper()->textEditor()->m_sFilePath = tmpFilePath;
+    pWindow->currentWrapper()->textEditor()->m_qstrTruePath = tmpFilePath;
+
+    QByteArray encoding("GB18030");
+    QByteArray utfData("\u4e2d\u6587\u6d4b\u8bd5\u4e00\u4e8c\u4e09\u56db\u0031\u0032\u0033\u0034\u0035\u0036\u0037"
+                       "\u0038\u0039\u0061\u0062\u0063\u0064\u0065\u0066\u0067\u0068");
+    pWindow->currentWrapper()->textEditor()->setPlainText(QString::fromUtf8(utfData));
+
+    Stub stubNotices;
+    stubNotices.set(ADDR(EditWrapper, hideWarningNotices), hideWarningNotices_stub);
+    intvalue = 1;
+    typedef int (*Fptr)(QFileDialog *);
+    Fptr fptr = (Fptr)(&QFileDialog::exec);
+    Stub s1;
+    s1.set(fptr,retintstub);
+
+    intvalue = 1;
+    bool bRet = pWindow->currentWrapper()->saveFile(encoding);
+    EXPECT_TRUE(bRet);
+
+    QFile tmpFile(tmpFilePath);
+    EXPECT_TRUE(tmpFile.exists());
+    QByteArray saveData;
+    if (tmpFile.open(QFile::ReadOnly | QFile::Text)) {
+        saveData = tmpFile.readAll();
+        tmpFile.close();
+    }
+
+    QTextCodec *codec = QTextCodec::codecForName(encoding);
+    EXPECT_EQ(codec->fromUnicode(utfData), saveData);
+
+    pWindow->deleteLater();
+}
+
+
 //bool saveAsFile_001(const QString &newFilePath, QByteArray encodeName);
 TEST(UT_Editwrapper_saveAsFile_001, UT_Editwrapper_saveAsFile_001)
 {
@@ -269,7 +286,7 @@ TEST(UT_Editwrapper_saveAsFile_001, UT_Editwrapper_saveAsFile_001)
     pWindow->currentWrapper()->textEditor()->insertTextEx(pWindow->currentWrapper()->textEditor()->textCursor(),
                                                           QString("12345"));
     bool bRet = pWindow->currentWrapper()->saveAsFile(QString(), QByteArray("UTF-8"));
-    ASSERT_TRUE(bRet == false);
+    EXPECT_FALSE(bRet);
 
     pWindow->deleteLater();
 }
@@ -282,31 +299,24 @@ bool saveAsFile_002_stub()
 //bool saveAsFile_001(const QString &newFilePath, QByteArray encodeName);
 TEST(UT_Editwrapper_saveAsFile, UT_Editwrapper_saveAsFile_002)
 {
-    /*
     Window *pWindow = new Window();
     pWindow->addBlankTab(QString());
     pWindow->currentWrapper()->textEditor()->insertTextEx(pWindow->currentWrapper()->textEditor()->textCursor(),
                                                           QString("12345"));
     QString newFilePaht(pWindow->currentWrapper()->textEditor()->getTruePath());
     bool bRet = pWindow->currentWrapper()->saveAsFile(newFilePaht, QByteArray("UTF-8"));
-    if (bRet == false) {
-        Stub stub;
-        stub.set(pWindow->currentWrapper()->saveAsFile(), saveAsFile_002_stub());
-    }
-    ASSERT_TRUE(bRet == true);
+    EXPECT_TRUE(bRet);
 
     pWindow->deleteLater();
-    */
 }
 
 TEST(UT_Editwrapper_saveAsFile, UT_Editwrapper_saveAsFile_003)
 {
-    /*
     Window *pWindow = new Window();
     pWindow->addBlankTab(QString());
     pWindow->currentWrapper()->textEditor()->insertTextEx(pWindow->currentWrapper()->textEditor()->textCursor(),
                                                           QString("12345"));
-
+    intvalue = 1;
     typedef int (*Fptr)(QFileDialog *);
     Fptr fptr = (Fptr)(&QFileDialog::exec);
     Stub s1;
@@ -314,7 +324,6 @@ TEST(UT_Editwrapper_saveAsFile, UT_Editwrapper_saveAsFile_003)
 
     Stub s2;
     s2.set(ADDR(QString,isEmpty),retfalsestub);
-
     Stub s3;
     s3.set(ADDR(QFileDialog,selectedFiles),retstringliststub);
 
@@ -325,9 +334,69 @@ TEST(UT_Editwrapper_saveAsFile, UT_Editwrapper_saveAsFile_003)
 
     bool bRet = pWindow->currentWrapper()->saveAsFile();
 
-    EXPECT_NE(bRet,true);
+    EXPECT_TRUE(bRet);
+    pWindow->deleteLater();
+}
+
+// bool saveAsFile(const QString &newFilePath, const QByteArray &encodeName);
+TEST(UT_Editwrapper_saveAsFile, UT_Editwrapper_saveFile_with_change_encoding)
+{
+    Window *pWindow = new Window;
+    QString saveAsPath("/tmp/ut_saveAsFile.txt");
+    QByteArray encoding("GB18030");
+    // Utf8 Text: 中文测试一二三四123456789abcdefgh
+    QByteArray utfData("\u4e2d\u6587\u6d4b\u8bd5\u4e00\u4e8c\u4e09\u56db\u0031\u0032\u0033\u0034\u0035\u0036\u0037"
+                       "\u0038\u0039\u0061\u0062\u0063\u0064\u0065\u0066\u0067\u0068");
+    pWindow->addBlankTab(QString());
+    pWindow->currentWrapper()->textEditor()->setPlainText(QString::fromUtf8(utfData));
+
+    // 默认文本编码为 UTF-8, 转换为 GB18030
+    bool ret = pWindow->currentWrapper()->saveAsFile(saveAsPath, encoding);
+    EXPECT_TRUE(ret);
+
+    QFile saveAsFile(saveAsPath);
+    EXPECT_TRUE(saveAsFile.open(QFile::ReadOnly | QFile::Text));
+    QByteArray saveData = saveAsFile.readAll();
+    saveAsFile.close();
+    saveAsFile.remove();
+
+    QTextCodec *codec = QTextCodec::codecForName(encoding);
+    EXPECT_EQ(codec->fromUnicode(utfData), saveData);
+
+    pWindow->deleteLater();
+}
+
+// bool saveAsFile(const QString &newFilePath, const QByteArray &encodeName);
+TEST(UT_Editwrapper_saveAsFile, UT_Editwrapper_saveFile_with_error_encoding)
+{
+    Window *pWindow = new Window;
+    QString saveAsPath("/tmp/ut_saveAsFile.txt");
+    QByteArray errEncoding("ERROR-ENCODING");
+    // Utf8 Text: 中文测试一二三四123456789abcdefgh
+    QByteArray utfData("\u4e2d\u6587\u6d4b\u8bd5\u4e00\u4e8c\u4e09\u56db\u0031\u0032\u0033\u0034\u0035\u0036\u0037"
+                       "\u0038\u0039\u0061\u0062\u0063\u0064\u0065\u0066\u0067\u0068");
+    pWindow->addBlankTab(QString());
+    pWindow->currentWrapper()->textEditor()->setPlainText(QString::fromUtf8(utfData));
+
+    // 默认文本编码为 UTF-8, 转换为 GB18030
+    bool ret = pWindow->currentWrapper()->saveAsFile(saveAsPath, errEncoding);
+    EXPECT_FALSE(ret);
+
+    pWindow->deleteLater();
+}
+
+// bool saveAsFile(const QString &newFilePath, const QByteArray &encodeName);
+TEST(UT_Editwrapper_saveAsFile, UT_Editwrapper_saveFile_with_empty_data)
+{
+    Window *pWindow = new Window;
+    QString saveAsPath("/tmp/ut_saveAsFile.txt");
+    pWindow->addBlankTab(QString());
+
+    // 默认文本编码为 UTF-8, 转换为 GB18030
+    bool ret = pWindow->currentWrapper()->saveAsFile(saveAsPath, "UTF-8");
+    EXPECT_TRUE(ret);
+
     pWindow->deleteLater();
-    */
 }
 
 //void updatePath(const QString &file);
@@ -509,7 +578,9 @@ TEST(UT_Editwrapper_saveDraftFile, UT_Editwrapper_saveDraftFile_001)
     fptr fileDialogExec = (fptr)(&QDialog::exec);
     Stub stub;
     stub.set(fileDialogExec, saveDraftFile001_exec_stub);
-    pWindow->currentWrapper()->saveDraftFile();
+    QString newFilePath;
+    pWindow->currentWrapper()->saveDraftFile(newFilePath);
+    EXPECT_EQ(pWindow->m_tabbar->currentPath(), newFilePath);
 
     pWindow->deleteLater();
 }
@@ -528,7 +599,42 @@ TEST(UT_Editwrapper_saveDraftFile, UT_Editwrapper_saveDraftFile_002)
     fptr fileDialogExec = (fptr)(&QDialog::exec);
     Stub stub;
     stub.set(fileDialogExec, saveDraftFile002_exec_stub);
-    pWindow->currentWrapper()->saveDraftFile();
+    QString newFilePath;
+    pWindow->currentWrapper()->saveDraftFile(newFilePath);
+    EXPECT_TRUE((newFilePath.isEmpty()));
+
+    pWindow->deleteLater();
+}
+
+// QString getComboBoxValue(const QString &text) const;
+QString stubGetComboBoxValue(const QString &text) {
+    Q_UNUSED(text)
+    return QString("GB18030");
+}
+
+TEST(UT_Editwrapper_saveDraftFile, saveDraftFile_ChangeSaveEncode_EncodeChange)
+{
+    Window *pWindow = new Window();
+    pWindow->addBlankTab(QString());
+    pWindow->currentWrapper()->m_pTextEdit->setPlainText(QString::fromUtf8("123abc中文测试一二三四"));
+
+    QString convertEncode("GB18030");
+    pWindow->currentWrapper()->m_sCurEncode = convertEncode;
+
+    typedef int (*fptr)(QDialog *);
+    fptr fileDialogExec = (fptr)(&QDialog::exec);
+    Stub stub;
+    stub.set(fileDialogExec, saveDraftFile001_exec_stub);
+
+    typedef QString (DFileDialog::*DialogFunc)(const QString &);
+    stub.set((DialogFunc)ADDR(DFileDialog, getComboBoxValue), stubGetComboBoxValue);
+
+    QString newFilePath;
+    pWindow->currentWrapper()->saveDraftFile(newFilePath);
+    EXPECT_EQ(pWindow->m_tabbar->currentPath(), newFilePath);
+
+    pWindow->currentWrapper()->readFile();
+    EXPECT_EQ(pWindow->currentWrapper()->m_sCurEncode, convertEncode);
 
     pWindow->deleteLater();
 }
@@ -565,6 +671,7 @@ TEST(UT_Editwrapper_readFile, UT_Editwrapper_readFile_002)
     Stub stub;
     stub.set(ADDR(EditWrapper, loadContent), readFile_stub_001);
     bool bRet = pWindow->currentWrapper()->readFile(QByteArray("UTF-8"));
+    EXPECT_EQ(QString("UTF-8"), pWindow->currentWrapper()->m_sCurEncode);
     ASSERT_FALSE(bRet);
 
     pWindow->deleteLater();
@@ -590,6 +697,8 @@ QByteArray FileLoadThreadRun(const QString &strFilePath, QByteArray *encode)
            return outData;
          }
     }
+
+    return QByteArray();
 }
 
 void handleFileLoadFinished_001_setPrintEnabled_stub()
@@ -602,6 +711,52 @@ void handleFileLoadFinished_001_setTextFinished_stub()
     return;
 }
 
+TEST(UT_Editwrapper_handleFilePreProcess, handleFilePreProcess_normalData_pass)
+{
+    Window *pWindow = new Window();
+    pWindow->addBlankTab(QString());
+    const QString filePath = QCoreApplication::applicationDirPath() + QString("/Makefile");
+    QByteArray encode = QByteArray();
+    const QByteArray retFileContent = FileLoadThreadRun(filePath, &encode);
+    // 预读取数据
+    pWindow->currentWrapper()->handleFilePreProcess(encode, retFileContent);
+
+    EXPECT_EQ(pWindow->currentWrapper()->m_bHasPreProcess, true);
+    // 均为UTF-8格式
+    EXPECT_EQ(pWindow->currentWrapper()->m_pTextEdit->toPlainText().toUtf8(), retFileContent);
+
+    pWindow->deleteLater();
+}
+
+QString disableToUnicode(const char *in, int length, QTextCodec::ConverterState *state = nullptr)
+{
+    Q_UNUSED(in)
+    Q_UNUSED(length)
+    Q_UNUSED(state)
+    return nullptr;
+}
+
+TEST(UT_Editwrapper_handleFilePreProcess, handleFilePreProcess_errorData_failed)
+{
+    Window *pWindow = new Window();
+    pWindow->addBlankTab(QString());
+    const QString filePath = QCoreApplication::applicationDirPath() + QString("/Makefile");
+    QByteArray encode = QByteArray();
+    const QByteArray retFileContent = FileLoadThreadRun(filePath, &encode);
+
+    // 定义重载函数类型
+    typedef  QString (QTextCodec::*toUnicodeType)(const char *, int, QTextCodec::ConverterState *) const;
+    Stub setToUnicodeDisabled_stub;
+    setToUnicodeDisabled_stub.set((toUnicodeType)ADDR(QTextCodec, toUnicode), disableToUnicode);
+    // 预读取数据
+    pWindow->currentWrapper()->handleFilePreProcess(encode, retFileContent);
+
+    EXPECT_EQ(pWindow->currentWrapper()->m_bHasPreProcess, true);
+    EXPECT_TRUE(pWindow->currentWrapper()->m_pTextEdit->toPlainText().isEmpty());
+
+    pWindow->deleteLater();
+}
+
 //void handleFileLoadFinished(const QByteArray &encode,const QString &content);
 TEST(UT_Editwrapper_handleFileLoadFinished, UT_Editwrapper_handleFileLoadFinished_001)
 {
@@ -614,7 +769,7 @@ TEST(UT_Editwrapper_handleFileLoadFinished, UT_Editwrapper_handleFileLoadFinishe
     setPrintEnabled_stub.set(ADDR(Window, setPrintEnabled), handleFileLoadFinished_001_setPrintEnabled_stub);
     Stub setTextFinished_stub;
     setTextFinished_stub.set(ADDR(TextEdit, setTextFinished), handleFileLoadFinished_001_setTextFinished_stub);
-    pWindow->currentWrapper()->handleFileLoadFinished(encode, retFileContent);
+    pWindow->currentWrapper()->handleFileLoadFinished(encode, retFileContent, false);
     ASSERT_TRUE(pWindow->currentWrapper()->m_pBottomBar->m_pEncodeMenu != nullptr);
 
     pWindow->deleteLater();
@@ -660,7 +815,7 @@ TEST(UT_Editwrapper_handleFileLoadFinished, UT_Editwrapper_handleFileLoadFinishe
     stringList.push_back(c2);
 
 
-    pWindow->currentWrapper()->handleFileLoadFinished(encode, retFileContent);
+    pWindow->currentWrapper()->handleFileLoadFinished(encode, retFileContent, false);
     ASSERT_TRUE(pWindow->currentWrapper()->m_pBottomBar->m_pEncodeMenu != nullptr);
 
     pWindow->deleteLater();
@@ -707,7 +862,7 @@ TEST(UT_Editwrapper_handleFileLoadFinished, UT_Editwrapper_handleFileLoadFinishe
     stringList.push_back(c2);
 
 
-    pWindow->currentWrapper()->handleFileLoadFinished(encode, retFileContent);
+    pWindow->currentWrapper()->handleFileLoadFinished(encode, retFileContent, false);
     ASSERT_TRUE(pWindow->currentWrapper()->m_pBottomBar->m_pEncodeMenu != nullptr);
 
     pWindow->deleteLater();
@@ -715,6 +870,23 @@ TEST(UT_Editwrapper_handleFileLoadFinished, UT_Editwrapper_handleFileLoadFinishe
     d = nullptr;
 }
 
+TEST(UT_Editwrapper_handleFileLoadFinished, UT_Editwrapper_handleFileLoadFinished_004_error)
+{
+    Window *pWindow = new Window();
+    pWindow->addBlankTab(QString());
+    const QString filePath = QCoreApplication::applicationDirPath() + QString("/Makefile");
+    QByteArray encode = QByteArray();
+    const QByteArray retFileContent = FileLoadThreadRun(filePath, &encode);
+    Stub setPrintEnabled_stub;
+    setPrintEnabled_stub.set(ADDR(Window, setPrintEnabled), handleFileLoadFinished_001_setPrintEnabled_stub);
+    Stub setTextFinished_stub;
+    setTextFinished_stub.set(ADDR(TextEdit, setTextFinished), handleFileLoadFinished_001_setTextFinished_stub);
+    pWindow->currentWrapper()->handleFileLoadFinished(encode, retFileContent, true);
+    EXPECT_FALSE(pWindow->currentWrapper()->textEditor()->getReadOnlyPermission());
+    EXPECT_TRUE(pWindow->currentWrapper()->textEditor()->getReadOnlyMode());
+
+    pWindow->deleteLater();
+}
 
 ////重新加载文件编码 1.文件修改 2.文件未修改处理逻辑一样 切换编码重新加载和另存为 梁卫东
 //bool reloadFileEncode(QByteArray encode);
@@ -909,27 +1081,61 @@ TEST(UT_Editwrapper_reloadFileEncode, UT_Editwrapper_reloadFileEncode_008)
     pWindow->deleteLater();
 }
 
-TEST(UT_Editwrapper_reloadFileEncode, UT_Editwrapper_reloadFileEncode_009)
+bool reloadFileEncode_BeforeDeraftEdit_getModified_stub()
+{
+    return true;
+}
+
+int reloadFileEncode_BeforeDeraftEdit_exec_save_stub()
+{
+    return 1;
+}
+
+TEST(UT_Editwrapper_reloadFileEncode, reloadFileEncode_BeforeDeraftEdit_ChangeEncode)
 {
-    /*
     Window *pWindow = new Window();
     pWindow->addBlankTab(QString());
-    pWindow->currentWrapper()->textEditor()->insertTextEx(pWindow->currentWrapper()->textEditor()->textCursor(),
-                                                          QString("12345"));
+    pWindow->currentWrapper()->textEditor()->setPlainText(QString::fromUtf8("123abc中文测试"));
+
+    Stub getModified_stub;
+    getModified_stub.set(ADDR(TextEdit, getModified), reloadFileEncode_BeforeDeraftEdit_getModified_stub);
     typedef int (*fptr)(QDialog *);
     fptr qDialogExec = (fptr)(&QDialog::exec);
-    Stub s1;
-    s1.set(qDialogExec, retintstub);
+    Stub stub;
+    stub.set(qDialogExec, reloadFileEncode_BeforeDeraftEdit_exec_save_stub);
 
-    Stub s2;
-    s2.set(ADDR(TextEdit,getModified),rettruestub);
+    QByteArray convertEncode("GB18030");
+    bool bRet = pWindow->currentWrapper()->reloadFileEncode(convertEncode);
+    EXPECT_TRUE(bRet);
+    EXPECT_EQ(convertEncode, pWindow->currentWrapper()->m_sCurEncode.toUtf8());
 
-    intvalue = 1;
-    bool bRet = pWindow->currentWrapper()->reloadFileEncode(QByteArray());
-    ASSERT_TRUE(bRet);
+    pWindow->deleteLater();
+}
+
+TEST(UT_Editwrapper_reloadFileEncode, reloadFileEncode_SaveFileChangeCode_ChangeEncode)
+{
+    Window *pWindow = new Window();
+    pWindow->addBlankTab(QString());
+    pWindow->currentWrapper()->textEditor()->setPlainText(QString::fromUtf8("123abc中文测试"));
+
+    Stub getModified_stub;
+    getModified_stub.set(ADDR(TextEdit, getModified), reloadFileEncode_BeforeDeraftEdit_getModified_stub);
+    typedef int (*fptr)(QDialog *);
+    fptr qDialogExec = (fptr)(&QDialog::exec);
+    Stub stub;
+    stub.set(qDialogExec, reloadFileEncode_BeforeDeraftEdit_exec_save_stub);
+
+    QString newFilePath;
+    pWindow->currentWrapper()->saveDraftFile(newFilePath);
+    pWindow->currentWrapper()->textEditor()->insertTextEx(pWindow->currentWrapper()->textEditor()->textCursor(),
+                                                          QString::fromUtf8("中文测试2"));
+
+    QByteArray convertEncode("GB18030");
+    bool bRet = pWindow->currentWrapper()->reloadFileEncode(convertEncode);
+    EXPECT_TRUE(bRet);
+    EXPECT_EQ(convertEncode, pWindow->currentWrapper()->m_sCurEncode.toUtf8());
 
     pWindow->deleteLater();
-    */
 }
 
 int reloadModifyFile_001_exec_stub()
@@ -1001,7 +1207,8 @@ TEST(UT_Editwrapper_reloadModifyFile, UT_Editwrapper_reloadModifyFile_003)
     Stub stub;
     stub.set(qDialogExec, reloadModifyFile_003_exec_stub);
     pWindow->currentWrapper()->reloadModifyFile();
-    ASSERT_FALSE(pWindow->currentWrapper()->saveDraftFile());
+    QString newFilePath;
+    ASSERT_FALSE(pWindow->currentWrapper()->saveDraftFile(newFilePath));
 
     pWindow->deleteLater();
 }
@@ -1201,3 +1408,47 @@ TEST(UT_Editwrapper_loadContent, UT_Editwrapper_loadContent_002)
     window->deleteLater();
 }
 
+TEST(UT_Editwrapper_reloadFileHighlight, reloadFileHighlight_ChangeDefinition_Success)
+{
+    Window* window = new Window();
+    EditWrapper* wra = new EditWrapper(window);
+    wra->m_pTextEdit->setPlainText("#include <iostream>;\n"
+                                   "int main(int argc, char *argv[]) { }");
+    const QString definitionName("C++");
+    wra->reloadFileHighlight(definitionName);
+    EXPECT_FALSE(wra->m_bHighlighterAll);
+    EXPECT_TRUE(wra->m_Definition.isValid());
+    EXPECT_EQ(wra->m_Definition.name(), definitionName);
+    EXPECT_NE(wra->m_pSyntaxHighlighter, nullptr);
+
+    wra->reloadFileHighlight(QString("None"));
+    EXPECT_FALSE(wra->m_bHighlighterAll);
+    EXPECT_FALSE(wra->m_Definition.isValid());
+    EXPECT_EQ(wra->m_pSyntaxHighlighter, nullptr);
+
+    wra->deleteLater();
+    window->deleteLater();
+}
+
+TEST(UT_Editwrapper_reloadFileHighlight, reloadFileHighlight_SingleLineText_Success)
+{
+    Window* window = new Window();
+    EditWrapper* wra = new EditWrapper(window);
+    wra->m_pTextEdit->setPlainText("import time");
+    auto firstBlock = wra->m_pTextEdit->document()->firstBlock();
+    auto formats = firstBlock.layout()->formats();
+    EXPECT_TRUE(formats.isEmpty());
+
+    const QString definitionName("Python");
+    wra->reloadFileHighlight(definitionName);
+    EXPECT_TRUE(wra->m_Definition.isValid());
+    EXPECT_EQ(wra->m_Definition.name(), definitionName);
+    EXPECT_NE(wra->m_pSyntaxHighlighter, nullptr);
+
+    firstBlock = wra->m_pTextEdit->document()->firstBlock();
+    formats = firstBlock.layout()->formats();
+    EXPECT_FALSE(formats.isEmpty());
+
+    wra->deleteLater();
+    window->deleteLater();
+}
